@@ -20,24 +20,38 @@
 #define _CHAT_WIDGET_INCLUDED
 
 #include <QWidget>
+#include <QListWidget>
 #include <QString>
 #include <QGridLayout>
 
+#include "SDLs.h"
+
 class QTextBrowser;
 class QLineEdit;
 class QListWidget;
+class QSettings;
+class SDLInteraction;
 
 class HWChatWidget : public QWidget
 {
   Q_OBJECT
 
  public:
-  HWChatWidget(QWidget* parent=0);
+  HWChatWidget(QWidget* parent, QSettings * gameSettings, SDLInteraction * sdli, bool notify);
+  void loadLists(const QString & nick);
+  void saveLists(const QString & nick);
+  void setShowReady(bool s);
+
+private:
+  void loadList(QStringList & list, const QString & file);
+  void saveList(QStringList & list, const QString & file);
+  void updateIcon(QListWidgetItem *item);
+  void updateIcons();
 
  public slots:
   void onChatString(const QString& str);
   void onServerMessage(const QString& str);
-  void nickAdded(const QString& nick);
+  void nickAdded(const QString& nick, bool notifyNick);
   void nickRemoved(const QString& nick);
   void clear();
   void setReadyStatus(const QString & nick, bool isReady);
@@ -48,22 +62,37 @@ class HWChatWidget : public QWidget
   void kick(const QString & str);
   void ban(const QString & str);
   void info(const QString & str);
+  void follow(const QString &);
 
  private:
   QGridLayout mainLayout;
   QTextBrowser* chatText;
   QStringList chatStrings;
+  QStringList ignoreList, friendsList;
   QListWidget* chatNicks;
   QLineEdit* chatEditLine;
   QAction * acInfo;
   QAction * acKick;
   QAction * acBan;
+  QAction * acFollow;
+  QAction * acIgnore;
+  QAction * acFriend;
+  QSettings * gameSettings;
+  SDLInteraction * sdli;
+  Mix_Chunk *sound[4];
+  bool notify;
+  bool showReady;
 
  private slots:
   void returnPressed();
   void onBan();
   void onKick();
   void onInfo();
+  void onFollow();
+  void onIgnore();
+  void onFriend();
+  void chatNickDoubleClicked(QListWidgetItem * item);
+  void chatNickSelected(int index);
 };
 
 #endif // _CHAT_WIDGET_INCLUDED
