@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="de">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -6,6 +8,20 @@
         <translation>Neu</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>Nie</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>Jede Runde</numerusform>
+            <numerusform>Jede %1. Runde</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -25,16 +41,31 @@
         <translation>Spielprofile bearbeiten</translation>
     </message>
 </context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation>%1 *** %2 wurde aus deiner Ignorierliste entfernt</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation>%1 *** %2 wurde in deine Ignorierliste aufgenommen</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation>%1 *** %2 wurde aus deiner Freundesliste entfernt</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation>%1 *** %2 wurde in deine Freundesliste aufgenommen</translation>
+    </message>
+</context>
 <context>
     <name>HWForm</name>
     <message>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>Bitte wähle einen Eintrag aus der Liste aus</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -51,13 +82,13 @@
         <source>new</source>
         <translation>Neu</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>Bitte wähle einen Eintrag aus der obigen Liste</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>Fehler beim Einlesen der Trainings-Konfigurationsdatei</translation>
-    </message>
     <message>
         <source>en.txt</source>
         <translation>de.txt</translation>
@@ -105,6 +136,38 @@
         <source>Wacky</source>
         <translation>Verrückt</translation>
     </message>
+    <message>
+        <source>Tunnel size</source>
+        <translation type="obsolete">Tunnelgröße</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Typ</translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation>Kleine Tunnel</translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation>Mittlere Tunnel</translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation>Große Tunnel</translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation>Kleine schwebende Inseln</translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation>Mittlere schwebende Inseln</translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation>Große schwebende Inseln</translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -186,16 +249,40 @@ wähle einen anderen Spitznamen:</translation>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>Servernachricht:</translation>
+        <translation type="obsolete">Servernachricht:</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>Servernachricht festlegen</translation>
+        <translation type="obsolete">Servernachricht festlegen</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
         <translation>Zwischenspeicher leeren</translation>
     </message>
+    <message>
+        <source>Fetch data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set data</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageConnecting</name>
@@ -221,6 +308,20 @@ wähle einen anderen Spitznamen:</translation>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
         <translation>&lt;p&gt;Der Preis für den besten Schuss geht an &lt;b&gt;%1&lt;/b&gt; mit &lt;b&gt;%2&lt;/b&gt; Punkten.&lt;/p&gt;</translation>
     </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Der blutigste Kämpfer ist &lt;b&gt;%1&lt;/b&gt; mit &lt;b&gt;%2&lt;/b&gt; Opfer in einer Runde.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Der blutigste Kämpfer ist &lt;b&gt;%1&lt;/b&gt; mit &lt;b&gt;%2&lt;/b&gt; Opfern in einer Runde.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Insgesamt fand &lt;b&gt;%1&lt;/b&gt; Igel ein trauriges Ende in dieser Runde.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Insgesamt fanden &lt;b&gt;%1&lt;/b&gt; Igel ein trauriges Ende in dieser Runde.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageMain</name>
@@ -247,8 +348,8 @@ wähle einen anderen Spitznamen:</translation>
         <translation>Fehler</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
-        <translation>Bitte einen Server aus der Liste auswählen</translation>
+        <source>Please select server from the list above</source>
+        <translation>Bitte wähle einen Eintrag aus der Liste aus</translation>
     </message>
 </context>
 <context>
@@ -280,12 +381,20 @@ wähle einen anderen Spitznamen:</translation>
         <translation>Team bearbeiten</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>Waffen-Set</translation>
+        <source>Delete team</source>
+        <translation>Team löschen</translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>Bearbeiten</translation>
+        <source>New weapon scheme</source>
+        <translation>Neue Waffenzusammenstellung</translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation>Waffenzusammenstellung bearbeiten</translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation>Waffenzusammenstellung löschen</translation>
     </message>
 </context>
 <context>
@@ -294,10 +403,6 @@ wähle einen anderen Spitznamen:</translation>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>Bitte einen Eintrag aus der Liste auswählen</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -318,6 +423,10 @@ wähle einen anderen Spitznamen:</translation>
         <source>Cannot delete file</source>
         <translation>Datei kann nicht gelöscht werden</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>Bitte einen Eintrag aus der Liste auswählen</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -337,18 +446,10 @@ wähle einen anderen Spitznamen:</translation>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>Bitte einen Raumnamen eingeben</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>Bitte einen Raum aus der Liste auswählen</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>Verwalten</translation>
@@ -389,6 +490,32 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
         <translation>Waffenzusammenstellungen bestimmen, welche Waffen wann und in welchen Mengen zur Verfügung stehen.</translation>
     </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation>
+            <numerusform>Es befindet sich %1 Spieler in diesem Raum.</numerusform>
+            <numerusform>Es befinden sich %1 Spieler in diesem Raum.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation>
+            <numerusform>Es nimmt %1 Team in diesem Raum teil.</numerusform>
+            <numerusform>Es nehmen %1 Teams in diesem Raum teil.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Bitte einen Raumnamen eingeben</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>Bitte einen Raum aus der Liste auswählen</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
+        <translation>Zufallslabyrinth</translation>
+    </message>
 </context>
 <context>
     <name>PageScheme</name>
@@ -452,6 +579,30 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
         <source>All hogs have a personal forcefield</source>
         <translation>Alle Igel haben ein eigenes Schutzschild</translation>
     </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>Gespielt wird in zufälliger Reihenfolge.</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>Beschütze deinen König! Ohne ihn hast du verloren.</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>Platziere deine Igel selbständig vor Rundenbeginn.</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation>Alle Teams mit gleicher Farbe teilen sich den gleichen Waffenvorrat.</translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation>Platziere keine Bauträger auf Zufallskarten.</translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -513,6 +664,26 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
         <source>Ban</source>
         <translation>Verbannen</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>Folgen</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation>Ignorieren</translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation>Als Freund hinzufügen</translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation>Nicht mehr ignorieren</translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation>Als Freund entfernen</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -522,7 +693,7 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
     </message>
     <message>
         <source>Enable sound</source>
-        <translation>Sound an</translation>
+        <translation>Klänge im Spiel</translation>
     </message>
     <message>
         <source>Show FPS</source>
@@ -534,7 +705,7 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
     </message>
     <message>
         <source>Enable music</source>
-        <translation>Musik an</translation>
+        <translation>Musik im Spiel</translation>
     </message>
     <message>
         <source>Frontend fullscreen</source>
@@ -548,20 +719,32 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
         <source>Check for updates at startup</source>
         <translation>Beim Start nach neuen Versionen suchen</translation>
     </message>
-    <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation>Frontendeffekte (erfordert Neustart)</translation>
-    </message>
     <message>
         <source>Reduced quality</source>
         <translation>Niedrige Qualität</translation>
     </message>
+    <message>
+        <source>Show ammo menu tooltips</source>
+        <translation>Kurzinfos für Waffen anzeigen</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation>Klänge im Frontend</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation>Musik im Frontend</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
+        <translation>Animationen im Frontend</translation>
+    </message>
 </context>
 <context>
     <name>QComboBox</name>
     <message>
         <source>generated map...</source>
-        <translation>Generierte Karte...</translation>
+        <translation>Zufallskarte...</translation>
     </message>
     <message>
         <source>Human</source>
@@ -571,16 +754,24 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
         <source>Level</source>
         <translation>Stufe</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation>(Systemstandard)</translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation>Mission</translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation>Zufallslabyrinth...</translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
-    <message>
-        <source>Team</source>
-        <translation>Team</translation>
-    </message>
     <message>
         <source>Team Members</source>
-        <translation>Team-Mitglieder</translation>
+        <translation>Teammitglieder</translation>
     </message>
     <message>
         <source>Key binds</source>
@@ -618,6 +809,14 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
         <source>Basic Settings</source>
         <translation>Grundeinstellungen</translation>
     </message>
+    <message>
+        <source>Team Settings</source>
+        <translation>Teameinstellungen</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Verschiedenes</translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -687,7 +886,7 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
     </message>
     <message>
         <source>Damage Modifier</source>
-        <translation>Schadensmodifikatoren</translation>
+        <translation>Prozentualer Schaden</translation>
     </message>
     <message>
         <source>Turn Time</source>
@@ -721,6 +920,48 @@ Du kannst beitreten und zusehen oder du wartest bis die aktuelle Runde zu Ende i
         <source>Game scheme</source>
         <translation>Spielprofil</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation>% Blindgänger</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Name</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Typ</translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation>Grab</translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation>Flagge</translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation>Stimme</translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation>Sprache</translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation>Spiel neu starten, um Änderungen zu übernehmen</translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation>Pulverfässer</translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation>Diese SVN-Kopie ist noch in Entwicklung und sie ist mit anderen Versionen vielleicht nicht kompatibel.
+Einige Dinge könnten nicht funktionieren oder unvollständig sein. Benutzung auf eigene Gefahr!</translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -794,7 +1035,7 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
         <translation>Spitzname</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
+        <source>Please enter your nickname</source>
         <translation>Bitte gib deinen Spitznamen ein</translation>
     </message>
 </context>
@@ -860,6 +1101,10 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
         <source>Ready</source>
         <translation>Bereit</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation>Zufallsteam</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
@@ -902,6 +1147,14 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
         <source>Probabilities</source>
         <translation>Nachschub</translation>
     </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation>Kisteninhalt</translation>
+    </message>
+    <message>
+        <source>Delays</source>
+        <translation>Verzögerungen</translation>
+    </message>
 </context>
 <context>
     <name>TCPBase</name>
@@ -964,6 +1217,30 @@ konnte nicht geöffnet werden. Bitte überprüfen Sie Ihre Installation</transla
         <source>Add Mines</source>
         <translation>Minen hinzufügen</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation>Zufällige Reihenfolge</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation>Schützt den König</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation>Igel platzieren</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation>Gemeinsames Arsenal</translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation>Keine Bauträger</translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1246,5 +1523,289 @@ Statistik</translation>
         <source>Keyboard</source>
         <translation>Tastatur</translation>
     </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation>Maus: Linke Taste</translation>
+    </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation>Maus: Mittlere Taste</translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation>Maus: Rechte Taste</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation>Maus: Mausrad hoch</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation>Maus: Mausrad runter</translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation>Rückstelltaste</translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation>Tabulator</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Clear</translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation>Eingabetaste</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pause</translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation>Escape</translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation>Leertaste</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Entf</translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation>Ziffernblock 0</translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation>Ziffernblock 1</translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation>Ziffernblock 2</translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation>Ziffernblock 3</translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation>Ziffernblock 4</translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation>Ziffernblock 5</translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation>Ziffernblock 6</translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation>Ziffernblock 7</translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation>Ziffernblock 8</translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation>Ziffernblock 9</translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation>Ziffernblock ,</translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation>Ziffernblock /</translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation>Ziffernblock *</translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation>Ziffernblock -</translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation>Ziffernblock +</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation>Enter</translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation>Gleich</translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation>Hoch</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>Runter</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>Rechts</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>Links</translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation>Einfg</translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation>Pos1</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation>Ende</translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation>Bild hoch</translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation>Bild runter</translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation>Numlock</translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation>Feststelltaste</translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation>Rollen</translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation>Rechte Umschalttaste</translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation>Linke Umschalttaste</translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation>Strg rechts</translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation>Strg links</translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation>Alt rechts</translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation>Alt links</translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation>Meta rechts</translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation>Meta links</translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation>A-Taste</translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation>B-Taste</translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation>X-Taste</translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation>Y-Taste</translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation>Linke Schultertaste</translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation>Rechte Schultertaste</translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation>Zurück-Taste</translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation>Start-Taste</translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation>Linker Analogstick</translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation>Rechter Analogstick</translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation>Linker Analogstick (Rechts)</translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation>Linker Analogstick (Links)</translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation>Linker Analogstick (Runter)</translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation>Linker Analogstick (Hoch)</translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation>Linker Auslöser</translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation>Rechter Auslöser</translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation>Rechter Analogstick (Runter)</translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation>Rechter Analogstick (Hoch)</translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation>Rechter Analogstick (Rechts)</translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
+        <translation>Rechter Analogstick (Links)</translation>
+    </message>
+    <message>
+        <source>DPad</source>
+        <translation>Steuerkreuz</translation>
+    </message>
 </context>
 </TS>
