@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="en">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -6,6 +8,20 @@
         <translation>new</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>Never</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>Each turn</numerusform>
+            <numerusform>Every %1 turns</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -25,6 +41,25 @@
         <translation>Edit schemes</translation>
     </message>
 </context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation>%1 *** %2 has been removed from your ignore list</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation>%1 *** %2 has been added to your ignore list</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation>%1 *** %2 has been removed from your friends list</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation>%1 *** %2 has been added to your friends list</translation>
+    </message>
+</context>
 <context>
     <name>HWForm</name>
     <message>
@@ -35,10 +70,6 @@
         <source>Error</source>
         <translation>Error</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>Please, select record from the list above</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -51,13 +82,13 @@
         <source>Cannot save record to file %1</source>
         <translation>Cannot save record to file %1</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>Please select record from the list above</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>Error reading training config file</translation>
-    </message>
     <message>
         <source>en.txt</source>
         <translation>en.txt</translation>
@@ -105,6 +136,34 @@
         <source>Wacky</source>
         <translation>Wacky</translation>
     </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished">Type</translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -185,16 +244,40 @@ or pick another nickname:</translation>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>Server message:</translation>
+        <translation type="obsolete">Server message:</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>Set message</translation>
+        <translation type="obsolete">Set message</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
         <translation>Clear Accounts Cache</translation>
     </message>
+    <message>
+        <source>Fetch data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set data</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageConnecting</name>
@@ -220,6 +303,20 @@ or pick another nickname:</translation>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
         <translation>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</translation>
     </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kill in a turn.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog was killed during this round.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehogs were killed during this round.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageMain</name>
@@ -246,8 +343,8 @@ or pick another nickname:</translation>
         <translation>Error</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
-        <translation>Please, select server from the list above</translation>
+        <source>Please select server from the list above</source>
+        <translation>Please select server from the list above</translation>
     </message>
 </context>
 <context>
@@ -279,12 +376,20 @@ or pick another nickname:</translation>
         <translation>Edit team</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>Weapons set</translation>
+        <source>Delete team</source>
+        <translation>Delete team</translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>Edit</translation>
+        <source>New weapon scheme</source>
+        <translation>New weapon scheme</translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation>Edit weapon scheme</translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation>Delete weapon scheme</translation>
     </message>
 </context>
 <context>
@@ -293,10 +398,6 @@ or pick another nickname:</translation>
         <source>Error</source>
         <translation>Error</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>Please, select record from the list</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -317,6 +418,10 @@ or pick another nickname:</translation>
         <source>Cannot delete file</source>
         <translation>Cannot delete file</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>Please select record from the list</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -336,54 +441,74 @@ or pick another nickname:</translation>
         <source>Error</source>
         <translation>Error</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>Please, enter room name</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>Please, select room from the list</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>Administration</translation>
     </message>
     <message>
         <source>Room Name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Room Name:</translation>
     </message>
     <message>
         <source>This game is in lobby.
 You may join and start playing once the game starts.</source>
-        <translation type="unfinished"></translation>
+        <translation>This game is in lobby.
+You may join and start playing once the game starts.</translation>
     </message>
     <message>
         <source>This game is in progress.
 You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
-        <translation type="unfinished"></translation>
+        <translation>This game is in progress.
+You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</translation>
     </message>
     <message>
         <source>%1 is the host. He may adjust settings and start the game.</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 is the host. He may adjust settings and start the game.</translation>
     </message>
     <message>
         <source>Random Map</source>
-        <translation type="unfinished"></translation>
+        <translation>Random Map</translation>
     </message>
     <message>
         <source>Games may be played on precreated or randomized maps.</source>
-        <translation type="unfinished"></translation>
+        <translation>Games may be played on precreated or randomized maps.</translation>
     </message>
     <message>
         <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
-        <translation type="unfinished"></translation>
+        <translation>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</translation>
     </message>
     <message>
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
+        <translation>The Weapon Scheme defines available weapons and their ammunition count.</translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation>
+            <numerusform>There is %1 client connected to this room.</numerusform>
+            <numerusform>There are %1 clients connected to this room.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation>
+            <numerusform>There is %1 team participating in this room.</numerusform>
+            <numerusform>There are %1 teams participating in this room.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Please enter room name</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>Please select room from the list</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -449,6 +574,30 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Delete</source>
         <translation>Delete</translation>
     </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>Order of play is random instead of in room order.</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>Play with a King. If he dies, your side dies.</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>Take turns placing your hedgehogs before the start of play.</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation>Ammo is shared between all teams that share a colour.</translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation>Disable girders when generating random maps.</translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -510,6 +659,26 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Ban</source>
         <translation>Ban</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>Follow</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation>Ignore</translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation>Add friend</translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation>Unignore</translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation>Remove friend</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -546,12 +715,24 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <translation>Append date and time to record file name</translation>
     </message>
     <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation type="unfinished"></translation>
+        <source>Reduced quality</source>
+        <translation>Reduced quality</translation>
     </message>
     <message>
-        <source>Reduced quality</source>
-        <translation type="unfinished"></translation>
+        <source>Show ammo menu tooltips</source>
+        <translation>Show ammo menu tooltips</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation>Enable frontend sounds</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation>Enable frontend music</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
+        <translation>Frontend effects</translation>
     </message>
 </context>
 <context>
@@ -568,6 +749,18 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Level</source>
         <translation>Level</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation>(System default)</translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation>Mission</translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
@@ -575,10 +768,6 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Team Members</source>
         <translation>Team Members</translation>
     </message>
-    <message>
-        <source>Team</source>
-        <translation>Team</translation>
-    </message>
     <message>
         <source>Fort</source>
         <translation>Fort</translation>
@@ -615,6 +804,14 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Basic Settings</source>
         <translation>Basic Settings</translation>
     </message>
+    <message>
+        <source>Team Settings</source>
+        <translation>Team Settings</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Misc</translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -718,6 +915,47 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Game scheme</source>
         <translation>Game scheme</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation>% Dud Mines</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Name</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Type</translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation>Grave</translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation>Flag</translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation>Voice</translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation>Locale</translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation>Restart game to apply</translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation>Explosives</translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -791,8 +1029,8 @@ Please check your installation</translation>
         <translation>Nickname</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
-        <translation>Please, enter your nickname</translation>
+        <source>Please enter your nickname</source>
+        <translation>Please enter your nickname</translation>
     </message>
 </context>
 <context>
@@ -857,36 +1095,40 @@ Please check your installation</translation>
         <source>Ready</source>
         <translation>Ready</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation>Random Team</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
     <message>
         <source>Room Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Room Name</translation>
     </message>
     <message>
         <source>C</source>
-        <translation type="unfinished"></translation>
+        <translation>C</translation>
     </message>
     <message>
         <source>T</source>
-        <translation type="unfinished"></translation>
+        <translation>T</translation>
     </message>
     <message>
         <source>Owner</source>
-        <translation type="unfinished"></translation>
+        <translation>Owner</translation>
     </message>
     <message>
         <source>Map</source>
-        <translation type="unfinished">Map</translation>
+        <translation>Map</translation>
     </message>
     <message>
         <source>Rules</source>
-        <translation type="unfinished"></translation>
+        <translation>Rules</translation>
     </message>
     <message>
         <source>Weapons</source>
-        <translation type="unfinished">Weapons</translation>
+        <translation>Weapons</translation>
     </message>
 </context>
 <context>
@@ -899,6 +1141,14 @@ Please check your installation</translation>
         <source>Probabilities</source>
         <translation>Probabilities</translation>
     </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation>Ammo in boxes</translation>
+    </message>
+    <message>
+        <source>Delays</source>
+        <translation>Delays</translation>
+    </message>
 </context>
 <context>
     <name>TCPBase</name>
@@ -961,6 +1211,30 @@ Please check your installation</translation>
         <source>Add Mines</source>
         <translation>Add Mines</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation>Random Order</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation>King</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation>Place Hedgehogs</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation>Clan Shares Ammo</translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation>Disable Girders</translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1116,97 +1390,97 @@ info</translation>
     </message>
     <message>
         <source>long jump</source>
-        <translation type="unfinished"></translation>
+        <translation>long jump</translation>
     </message>
     <message>
         <source>high jump</source>
-        <translation type="unfinished"></translation>
+        <translation>high jump</translation>
     </message>
 </context>
 <context>
     <name>binds (categories)</name>
     <message>
         <source>Basic controls</source>
-        <translation type="unfinished"></translation>
+        <translation>Basic controls</translation>
     </message>
     <message>
         <source>Weapon controls</source>
-        <translation type="unfinished"></translation>
+        <translation>Weapon controls</translation>
     </message>
     <message>
         <source>Camera and cursor controls</source>
-        <translation type="unfinished"></translation>
+        <translation>Camera and cursor controls</translation>
     </message>
     <message>
         <source>Other</source>
-        <translation type="unfinished">Other</translation>
+        <translation>Other</translation>
     </message>
 </context>
 <context>
     <name>binds (descriptions)</name>
     <message>
         <source>Move your hogs and aim:</source>
-        <translation type="unfinished"></translation>
+        <translation>Move your hogs and aim:</translation>
     </message>
     <message>
         <source>Traverse gaps and obstacles by jumping:</source>
-        <translation type="unfinished"></translation>
+        <translation>Traverse gaps and obstacles by jumping:</translation>
     </message>
     <message>
         <source>Fire your selected weapon or trigger an utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation>Fire your selected weapon or trigger an utility item:</translation>
     </message>
     <message>
         <source>Pick a weapon or a target location under the cursor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Pick a weapon or a target location under the cursor:</translation>
     </message>
     <message>
         <source>Switch your currently active hog (if possible):</source>
-        <translation type="unfinished"></translation>
+        <translation>Switch your currently active hog (if possible):</translation>
     </message>
     <message>
         <source>Pick a weapon or utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation>Pick a weapon or utility item:</translation>
     </message>
     <message>
         <source>Set the timer on bombs and timed weapons:</source>
-        <translation type="unfinished"></translation>
+        <translation>Set the timer on bombs and timed weapons:</translation>
     </message>
     <message>
         <source>Move the camera to the active hog:</source>
-        <translation type="unfinished"></translation>
+        <translation>Move the camera to the active hog:</translation>
     </message>
     <message>
         <source>Move the cursor or camera without using the mouse:</source>
-        <translation type="unfinished"></translation>
+        <translation>Move the cursor or camera without using the mouse:</translation>
     </message>
     <message>
         <source>Modify the camera&apos;s zoom level:</source>
-        <translation type="unfinished"></translation>
+        <translation>Modify the camera&apos;s zoom level:</translation>
     </message>
     <message>
         <source>Talk to your team or all participants:</source>
-        <translation type="unfinished"></translation>
+        <translation>Talk to your team or all participants:</translation>
     </message>
     <message>
         <source>Pause, continue or leave your game:</source>
-        <translation type="unfinished"></translation>
+        <translation>Pause, continue or leave your game:</translation>
     </message>
     <message>
         <source>Modify the game&apos;s volume while playing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Modify the game&apos;s volume while playing:</translation>
     </message>
     <message>
         <source>Toggle fullscreen mode:</source>
-        <translation type="unfinished"></translation>
+        <translation>Toggle fullscreen mode:</translation>
     </message>
     <message>
         <source>Take a screenshot:</source>
-        <translation type="unfinished"></translation>
+        <translation>Take a screenshot:</translation>
     </message>
     <message>
         <source>Toggle labels above hedgehogs:</source>
-        <translation type="unfinished"></translation>
+        <translation>Toggle labels above hedgehogs:</translation>
     </message>
 </context>
 <context>
@@ -1243,5 +1517,289 @@ info</translation>
         <source>Keyboard</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Delete</translation>
+    </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DPad</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
