@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="es">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -6,6 +8,20 @@
         <translation>Nuevo</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>Nunca</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>Cada turno</numerusform>
+            <numerusform>Cada %1 turnos</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -25,16 +41,31 @@
         <translation>Editar modos de juego</translation>
     </message>
 </context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation>%1 *** %2 ha sido eliminado de tu lista de ignorados</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation>%1 *** %2 has sido añadido a tu lista de ignorados</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation>%1 *** %2 ha sido eliminado de tu lista de amigos</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation>%1 *** %2 ha sido añadido a tu lista de amigos</translation>
+    </message>
+</context>
 <context>
     <name>HWForm</name>
     <message>
         <source>Error</source>
         <translation>Error</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>Por favor, seleccione una entrada de la lista</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -51,20 +82,20 @@
         <source>new</source>
         <translation>Nuevo</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>Por favor, selecciona una entrada de la lista</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>Se produjo un error a leer el fichero de entrenamiento</translation>
-    </message>
     <message>
         <source>en.txt</source>
         <translation>es.txt</translation>
     </message>
     <message>
         <source>Cannot open demofile %1</source>
-        <translation>No se pudo abrir el fichero de demo %1</translation>
+        <translation>No se pudo abrir la demo %1</translation>
     </message>
 </context>
 <context>
@@ -103,7 +134,39 @@
     </message>
     <message>
         <source>Wacky</source>
-        <translation>Alocado</translation>
+        <translation>Loco</translation>
+    </message>
+    <message>
+        <source>Tunnel size</source>
+        <translation type="obsolete">Tamaño del túnel</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Tipo</translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation>Túneles estrechos</translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation>Túneles normales</translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation>Túneles anchos</translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation>Islas pequeñas</translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation>Islas medianas</translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation>Islas grandes</translation>
     </message>
 </context>
 <context>
@@ -125,7 +188,7 @@
     <name>HWNewNet</name>
     <message>
         <source>The host was not found. Please check the host name and port settings.</source>
-        <translation>No se pudo establecer una conexión con el servidor. Por favor, compruebe que el nombre del servidor y el puerto son correctos.</translation>
+        <translation>No se pudo establecer una conexión con el servidor. Por favor, comprueba que el nombre del servidor y el puerto son correctos.</translation>
     </message>
     <message>
         <source>Connection refused</source>
@@ -185,16 +248,40 @@ o elige otro nick:</translation>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>Mensaje del servidor:</translation>
+        <translation type="obsolete">Mensaje del servidor:</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>Establecer mensaje</translation>
+        <translation type="obsolete">Establecer mensaje</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
         <translation>Vaciar caché de cuentas</translation>
     </message>
+    <message>
+        <source>Fetch data</source>
+        <translation>Obtener datos</translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation>Mensaje del servidor para la última versión:</translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation>Mensaje del servidor para versiones anteriores:</translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation>Número de protocolo de la última versión:</translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation>Vista previa del MOTD:</translation>
+    </message>
+    <message>
+        <source>Set data</source>
+        <translation>Enviar datos</translation>
+    </message>
 </context>
 <context>
     <name>PageConnecting</name>
@@ -218,7 +305,21 @@ o elige otro nick:</translation>
     <name>PageGameStats</name>
     <message>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
-        <translation>&lt;p&gt;El premio al mejor disparo es para &lt;b&gt;%1&lt;/b&gt; , con &lt;b&gt;%2&lt;/b&gt; puntos.&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;El premio al mejor disparo es para &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; puntos.&lt;/p&gt;</translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;El asesino más eficiente es &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; muerte en un solo turno.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;El asesino más eficiente es &lt;b&gt;%1&lt;/b&gt;, con &lt;b&gt;%2&lt;/b&gt; muertes en un solo turno.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Un total de &lt;b&gt;%1&lt;/b&gt; erizo murió esta ronda.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Un total de &lt;b&gt;%1&lt;/b&gt; erizos murieron esta ronda.&lt;/p&gt;</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -229,7 +330,7 @@ o elige otro nick:</translation>
     </message>
     <message>
         <source>Network Game (Play a game across a network)</source>
-        <translation>Juego en red (Jugar a través de una red)</translation>
+        <translation>Juego en red (Jugar a través de la red)</translation>
     </message>
 </context>
 <context>
@@ -246,15 +347,15 @@ o elige otro nick:</translation>
         <translation>Error</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
-        <translation>Por favor, seleccione un servidor de la lista</translation>
+        <source>Please select server from the list above</source>
+        <translation>Por favor, selecciona un servidor de la lista</translation>
     </message>
 </context>
 <context>
     <name>PageNetGame</name>
     <message>
         <source>Control</source>
-        <translation>Controles</translation>
+        <translation>Opciones</translation>
     </message>
 </context>
 <context>
@@ -279,12 +380,20 @@ o elige otro nick:</translation>
         <translation>Editar equipo</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>Nuevo set</translation>
+        <source>Delete team</source>
+        <translation>Borrar equipo</translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>Editar set</translation>
+        <source>New weapon scheme</source>
+        <translation>Nuevo set de armas</translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation>Editar set de armas</translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation>Borrar set de armas</translation>
     </message>
 </context>
 <context>
@@ -293,10 +402,6 @@ o elige otro nick:</translation>
         <source>Error</source>
         <translation>Error</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>Por favor, seleccione una entrada de la lista</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -307,7 +412,7 @@ o elige otro nick:</translation>
     </message>
     <message>
         <source>Enter new file name:</source>
-        <translation>Introduzca el nuevo nombre del fichero:</translation>
+        <translation>Introduce el nuevo nombre del fichero:</translation>
     </message>
     <message>
         <source>Cannot rename to</source>
@@ -317,6 +422,10 @@ o elige otro nick:</translation>
         <source>Cannot delete file</source>
         <translation>No se pudo eliminar el fichero</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>Por favor, selecciona una entrada de la lista</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -336,18 +445,10 @@ o elige otro nick:</translation>
         <source>Error</source>
         <translation>Error</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>Por favor, introduzca un nombre para la sala</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>Por favor, seleccione una sala de la lista</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>Parámetros del administrador</translation>
@@ -374,11 +475,11 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Random Map</source>
-        <translation>Mapa aleatorio</translation>
+        <translation>Terreno aleatorio</translation>
     </message>
     <message>
         <source>Games may be played on precreated or randomized maps.</source>
-        <translation>Las partidas pueden ser jugadas bien en mapas pre-creados o aleatorios.</translation>
+        <translation>Las partidas pueden ser jugadas bien en mapas pre-creados o generados aleatoriamente.</translation>
     </message>
     <message>
         <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
@@ -388,6 +489,32 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
         <translation>El set de armas define las armas y munición disponibles.</translation>
     </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation>
+            <numerusform>Hay %1 cliente en esta sala.</numerusform>
+            <numerusform>Hay %1 clientes en esta sala.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation>
+            <numerusform>Hay %1 equipo participando en esta sala.</numerusform>
+            <numerusform>Hay %1 equipos participando en esta sala.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Por favor, introduce un nombre para la sala</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>Por favor, selecciona una sala de la lista</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
+        <translation>Laberinto aleatorio</translation>
+    </message>
 </context>
 <context>
     <name>PageScheme</name>
@@ -425,31 +552,55 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Defend your fort and destroy the opponents, two team colours max!</source>
-        <translation>Defiende tu fuerte y destruye el de tus oponentes, 2 colores de equipo como máximo!</translation>
+        <translation>Defiende tu fuerte y destruye el de tus oponentes. ¡2 facciones como máximo!</translation>
     </message>
     <message>
         <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
-        <translation>Los equipos comenzarán en lados opuestos del terreno, 2 colores de equipo como máximo!</translation>
+        <translation>Los equipos comenzarán en lados opuestos del terreno. ¡2 facciones como máximo!</translation>
     </message>
     <message>
         <source>Land can not be destroyed!</source>
-        <translation>El terreno es indestructible!</translation>
+        <translation>¡El terreno es indestructible!</translation>
     </message>
     <message>
         <source>Add an indestructable border around the terrain</source>
-        <translation>Añade un borde indestructible alrededor del campo de juego</translation>
+        <translation>Añade un borde indestructible alrededor del campo de juego.</translation>
     </message>
     <message>
         <source>Lower gravity</source>
-        <translation>Baja gravedad</translation>
+        <translation>Baja gravedad.</translation>
     </message>
     <message>
         <source>Assisted aiming with laser sight</source>
-        <translation>Puntería asistida con mira láser</translation>
+        <translation>Una mira láser que te ayudará a apuntar.</translation>
     </message>
     <message>
         <source>All hogs have a personal forcefield</source>
-        <translation>Todos los erizos tienen un campo de fuerza personal</translation>
+        <translation>Todos los erizos tienen un campo de fuerza personal que los protege.</translation>
+    </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>El orden de los equipos en la partida es aleatorio en lugar de tal como se muestran en la sala.</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>El primero erizo del equipo es el Rey. Tu equipo pierde el juego si el rey muere, así que protégelo.</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>Los jugadores posicionan a mano su erizos por turnos antes de empezar a jugar.</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation>La munición se comparte entre los equipos de una misma facción.</translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation>Deshabilita las vigas en los mapas generados aleatoriamente.</translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation>Deshabilita los objetos en el terreno en los mapas generados aleatoriamente.</translation>
     </message>
 </context>
 <context>
@@ -460,14 +611,14 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Delete</source>
-        <translation>Eliminar</translation>
+        <translation>Borrar</translation>
     </message>
 </context>
 <context>
     <name>PageSinglePlayer</name>
     <message>
         <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
-        <translation>Partida sencilla (Una partida rápida contra la computadora, los ajustes se eligen automáticamente)</translation>
+        <translation>Partida sencilla (Una partida rápida contra la computadora; los ajustes se eligen automáticamente)</translation>
     </message>
     <message>
         <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
@@ -498,11 +649,11 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Restrict Joins</source>
-        <translation>Restringir la entrada</translation>
+        <translation>Impedir que entren más jugadores</translation>
     </message>
     <message>
         <source>Restrict Team Additions</source>
-        <translation>Restringir el añadido de equipos</translation>
+        <translation>Impedir que se añadan más equipos</translation>
     </message>
     <message>
         <source>Info</source>
@@ -512,6 +663,26 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
         <source>Ban</source>
         <translation>Banear</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>Vigilar</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation>Bloquear</translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation>Añadir amigo</translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation>Desbloquear</translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation>Eliminar amigo</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -521,7 +692,7 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Enable sound</source>
-        <translation>Habilitar sonido</translation>
+        <translation>Habilitar sonidos del juego</translation>
     </message>
     <message>
         <source>Show FPS</source>
@@ -529,11 +700,11 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Alternative damage show</source>
-        <translation>Mostrar daño de manera alternativa</translation>
+        <translation>Mostrar el daño según ocurre</translation>
     </message>
     <message>
         <source>Enable music</source>
-        <translation>Habilitar música</translation>
+        <translation>Habilitar música del juego</translation>
     </message>
     <message>
         <source>Frontend fullscreen</source>
@@ -541,26 +712,38 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Append date and time to record file name</source>
-        <translation>Agregar fecha y hora al nombre de fichero</translation>
+        <translation>Agregar fecha y hora al nombre de los ficheros</translation>
     </message>
     <message>
         <source>Check for updates at startup</source>
         <translation>Comprobar actualizaciones al iniciar</translation>
     </message>
     <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation>Efectos del interfaz (requiere reiniciar)</translation>
+        <source>Reduced quality</source>
+        <translation>Reducir efectos gráficos (para ordenadores lentos)</translation>
     </message>
     <message>
-        <source>Reduced quality</source>
-        <translation>Reducir calidad</translation>
+        <source>Show ammo menu tooltips</source>
+        <translation>Mostrar globos de ayuda sobre el armamento</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation>Habilitar sonidos del interfaz</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation>Habilitar música del interfaz</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
+        <translation>Habilitar efectos del interfaz</translation>
     </message>
 </context>
 <context>
     <name>QComboBox</name>
     <message>
         <source>generated map...</source>
-        <translation>mapa generado...</translation>
+        <translation>Terreno aleatorio...</translation>
     </message>
     <message>
         <source>Human</source>
@@ -570,13 +753,21 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
         <source>Level</source>
         <translation>Nivel</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation>(Predeterminado del sistema)</translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation>Laberinto aleatorio...</translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation>Misión</translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
-    <message>
-        <source>Team</source>
-        <translation>Equipo</translation>
-    </message>
     <message>
         <source>Team Members</source>
         <translation>Miembros del equipo</translation>
@@ -599,7 +790,7 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Weapons</source>
-        <translation>Armas</translation>
+        <translation>Sets de armas</translation>
     </message>
     <message>
         <source>Net game</source>
@@ -615,7 +806,15 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Basic Settings</source>
-        <translation>Opciones</translation>
+        <translation>Opciones básicas</translation>
+    </message>
+    <message>
+        <source>Team Settings</source>
+        <translation>Opciones del equipo</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Otras opciones</translation>
     </message>
 </context>
 <context>
@@ -642,7 +841,7 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Weapons</source>
-        <translation>Armas</translation>
+        <translation>Set de armas</translation>
     </message>
     <message>
         <source>Host:</source>
@@ -662,7 +861,7 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Net nick</source>
-        <translation>Apodo de red</translation>
+        <translation>Apodo</translation>
     </message>
     <message>
         <source>Server name:</source>
@@ -686,7 +885,7 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
     </message>
     <message>
         <source>Damage Modifier</source>
-        <translation>Modificador de daño</translation>
+        <translation>Modificador al daño</translation>
     </message>
     <message>
         <source>Turn Time</source>
@@ -720,6 +919,49 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
         <source>Game scheme</source>
         <translation>Modo de juego</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation>% minas defectuosas</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nombre</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Tipo</translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation>Lápida</translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation>Bandera</translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation>Voz</translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation>Idioma</translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation>Requiere reiniciar el juego</translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation>Esta es una versión experimental del juego y puede no ser compatible con otras versiones del mismo,
+así como carecer de algunas funcionalidades o simplemente funcionar mal. 
+¡Úsalo bajo tu propia responsalibidad!</translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation>Explosivos</translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -755,11 +997,11 @@ Puedes unirte como espectador, pero tendrás que esperar a que el juego termine
 Please check your installation</source>
         <translation>No de pudo abrir el directorio:
 %1
-Verifique su instalación</translation>
+Por favor, compruebe que el juego está debidamente instalado</translation>
     </message>
     <message>
         <source>Weapons</source>
-        <translation>Armas</translation>
+        <translation>Sets de armas</translation>
     </message>
     <message>
         <source>Can not edit default weapon set</source>
@@ -767,11 +1009,11 @@ Verifique su instalación</translation>
     </message>
     <message>
         <source>Can not delete default weapon set</source>
-        <translation>No se puede eliminar el set de armas predefinido</translation>
+        <translation>No se puede borrar el set de armas predefinido</translation>
     </message>
     <message>
         <source>Really delete this weapon set?</source>
-        <translation>¿Realmente desea eliminar este set de armas?</translation>
+        <translation>¿Realmente desea borrar este set de armas?</translation>
     </message>
 </context>
 <context>
@@ -793,8 +1035,8 @@ Verifique su instalación</translation>
         <translation>Nick</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
-        <translation>Por favor, introduce tu nick</translation>
+        <source>Please enter your nickname</source>
+        <translation>Por favor introduce tu nick</translation>
     </message>
 </context>
 <context>
@@ -837,7 +1079,7 @@ Verifique su instalación</translation>
     </message>
     <message>
         <source>Play demo</source>
-        <translation>Visualizar demo</translation>
+        <translation>Reproducir demo</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -859,6 +1101,10 @@ Verifique su instalación</translation>
         <source>Ready</source>
         <translation>Listo</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation>Equipo aleatorio</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
@@ -888,18 +1134,26 @@ Verifique su instalación</translation>
     </message>
     <message>
         <source>Weapons</source>
-        <translation>Armas</translation>
+        <translation>Set de armas</translation>
     </message>
 </context>
 <context>
     <name>SelWeaponWidget</name>
     <message>
         <source>Weapon set</source>
-        <translation>Set de armas</translation>
+        <translation>Cantidad inicial</translation>
     </message>
     <message>
         <source>Probabilities</source>
-        <translation>Probabilidades</translation>
+        <translation>Probabilidad</translation>
+    </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation>Munición en las cajas</translation>
+    </message>
+    <message>
+        <source>Delays</source>
+        <translation>Retraso</translation>
     </message>
 </context>
 <context>
@@ -933,7 +1187,7 @@ Verifique su instalación</translation>
     </message>
     <message>
         <source>Fort Mode</source>
-        <translation>Modo fuertes</translation>
+        <translation>Fuertes</translation>
     </message>
     <message>
         <source>Divide Teams</source>
@@ -963,6 +1217,30 @@ Verifique su instalación</translation>
         <source>Add Mines</source>
         <translation>Añadir minas</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation>Orden aleatorio</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation>Rey</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation>Posicionar erizos</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation>Compartir munición</translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation>Deshabilitar vigas</translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation>Deshabilitar decoraciones</translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1245,5 +1523,289 @@ los erizos</translation>
         <source>Keyboard</source>
         <translation>Teclado</translation>
     </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation>Ratón: botón izquierdo</translation>
+    </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation>Ratón: botón central</translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation>Ratón: botón derecho</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation>Ratón: rueda arriba</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation>Ratón: rueda abajo</translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation>Retroceso</translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation>Tabulador</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Supr</translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation>Intro</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausa</translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation>Esc</translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation>Barra espaciadora</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supr</translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation>Teclado numérico 0</translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation>Teclado numérico 1</translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation>Teclado numérico 2</translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation>Teclado numérico 3</translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation>Teclado numérico 4</translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation>Teclado numérico 5</translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation>Teclado numérico 6</translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation>Teclado numérico 7</translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation>Teclado numérico 8</translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation>Teclado numérico 9</translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation>Teclado numérico .</translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation>Teclado numérico /</translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation>Teclado numérico *</translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation>Teclado numérico -</translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation>Teclado numérico +</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation>Intro</translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation>Igual</translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation>Arriba</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>Abajo</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>Derecha</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>Izquierda</translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation>Insert</translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation>Inicio</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation>Fin</translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation>Re Pág</translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation>Av Pág</translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation>Bloq Num</translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation>Bloq Mayús</translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation>Bloq Despl</translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation>Shift derecho</translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation>Shift izquierdo</translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation>Ctrl derecho</translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation>Ctrl izquierdo</translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation>Alt Gr</translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation>Alt</translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation>Meta derecho</translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation>Meta izquierdo</translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation>Botón A</translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation>Botón B</translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation>Botón X</translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation>Botón Y</translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation>Botón LB</translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation>Botón RB</translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation>Botón atrás</translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation>Botón Start</translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation>Palanca izquierda</translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation>Palanca derecha</translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation>Palanca izquierda (derecha)</translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation>Palanca izquierda (izquierda)</translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation>Palanca izquierda (abajo)</translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation>Palanca izquierda (arriba)</translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation>Gatillo izquierdo</translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation>Gatillo derecho</translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation>Palanca derecha (abajo)</translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation>Palanca derecha (arriba)</translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation>Palanca derecha (derecha)</translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
+        <translation>Palanca derecha (izquierda)</translation>
+    </message>
+    <message>
+        <source>DPad</source>
+        <translation>DPad</translation>
+    </message>
 </context>
 </TS>
