@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="fi">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -6,6 +8,20 @@
         <translation>uusi</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>Ei koskaan</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>Joka vuorolla</numerusform>
+            <numerusform>Joka %1:s vuoro</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -25,6 +41,25 @@
         <translation>Muokkaa kaavaa</translation>
     </message>
 </context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation>%1 *** %2 on poistanut sinut huomiotta jättö-listaltaan</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation>%1 *** %2 on lisännyt sinut huomiotta jättö-listalleen</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation>%1 *** %2 on poistanut sinut kaverilistaltaan</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation>%1 *** %2 on lisännyt sinut kaverilistalleen</translation>
+    </message>
+</context>
 <context>
     <name>HWForm</name>
     <message>
@@ -35,10 +70,6 @@
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>Ole hyvä ja valitse nauhoite ylläolevasta listasta</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -51,13 +82,13 @@
         <source>Cannot save record to file %1</source>
         <translation>Nauhoitetta ei voitu tallentaa tiedostoon %1</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>Ole hyvä ja valitse nauhoite ylläolevasta listasta</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>Virhe luettaessa harjoituksen asetustiedostoa</translation>
-    </message>
     <message>
         <source>en.txt</source>
         <translation>fi.txt</translation>
@@ -105,6 +136,34 @@
         <source>Themes</source>
         <translation>Teemat</translation>
     </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished">Tyyppi</translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -167,11 +226,11 @@ tai valitse toinen nimimerkki:</translation>
     </message>
     <message>
         <source>%1 *** %2 has left</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2 poistui</translation>
     </message>
     <message>
         <source>%1 *** %2 has left (%3)</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2 poistui (%3)</translation>
     </message>
 </context>
 <context>
@@ -185,16 +244,40 @@ tai valitse toinen nimimerkki:</translation>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>Palvelimen viesti:</translation>
+        <translation type="obsolete">Palvelimen viesti:</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>Aseta viesti</translation>
+        <translation type="obsolete">Aseta viesti</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
         <translation>Tyhjennä käyttäjätili-välimuisti</translation>
     </message>
+    <message>
+        <source>Fetch data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set data</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageConnecting</name>
@@ -220,6 +303,20 @@ tai valitse toinen nimimerkki:</translation>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
         <translation>&lt;p&gt;Paras laukaus -mitalin voitti &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt; pisteellä&lt;/p&gt;</translation>
     </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Paras tappaja oli &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;yhdellä&lt;/b&gt; tapolla vuoron aikana&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Paras tappaja oli &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt;:llä tapolla &lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Yhteensä &lt;b&gt;yksi&lt;/b&gt; siili tapettiin tällä kierroksella.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Yhteensä &lt;b&gt;%1&lt;/b&gt; siiltä tapettiin tällä kierroksella.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageMain</name>
@@ -246,8 +343,8 @@ tai valitse toinen nimimerkki:</translation>
         <translation>Virhe</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
-        <translation>Ole hyvä, ja valitse palvelin ylläolevasta listasta</translation>
+        <source>Please select server from the list above</source>
+        <translation>Ole hyvä ja valitse palvelin ylläolevasta listasta</translation>
     </message>
 </context>
 <context>
@@ -279,12 +376,20 @@ tai valitse toinen nimimerkki:</translation>
         <translation>Muokkaa joukkuetta</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>Uusi asesetti</translation>
+        <source>Delete team</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>Muokkaa</translation>
+        <source>New weapon scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -293,10 +398,6 @@ tai valitse toinen nimimerkki:</translation>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>Ole hyvä ja valitse nauhoite listasta</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -317,6 +418,10 @@ tai valitse toinen nimimerkki:</translation>
         <source>Cannot delete file</source>
         <translation>Ei voida poistaa tiedostoa</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>Ole hyvä ja valitse nauhoite listasta</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -336,18 +441,10 @@ tai valitse toinen nimimerkki:</translation>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>Ole hyvä ja syötä huoneen nimi</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>Ole hyvä, ja valitse huone listalta</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>Ylläpitäjän ominaisuudet</translation>
@@ -388,6 +485,32 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
         <translation>Asesuunnitelma määrittelee saatavilla olevat aseet ja niiden panosmäärät.</translation>
     </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation>
+            <numerusform>Yksi asiakas on liittyneenä tähän huoneeseen</numerusform>
+            <numerusform>%1 asiakasta on liittyneenä tähän huoneeseen</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation>
+            <numerusform>Tässä huoneessa on osallistuneena yksi joukkue</numerusform>
+            <numerusform>Tässä huoneessa on osallistuneena %1 joukkuetta</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Ole hyvä ja syötä huoneen nimi</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>Ole hyvä ja valitse huone listalta</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageScheme</name>
@@ -451,6 +574,30 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>Pelaamisjärjestys on satunnainen huoneen järjestyksen sijaan.</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>Pelaa kuninkaalla. Jos hän kuolee, sinun jokkueesi häviää.</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>Sijoittakaa siilenne vuorotellen ennen pelin alkua.</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation>Ammukset ovat yhteiset saman värin kesken.</translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation>Kytke palkit pois päältä satunnaisissa kartoissa.</translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -512,6 +659,26 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>Ban</source>
         <translation>Anna porttikielto</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>Seuraa</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation>Jätä huomiotta</translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation>Lisää kaveriksi</translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation>Ota huomion</translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation>Poista kaverilistalta</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -547,14 +714,26 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>Append date and time to record file name</source>
         <translation>Lisää päivämäärä ja aika nauhoitusten tiedostonimeen</translation>
     </message>
-    <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation>Käyttöliittymätehosteet (vaatii uudelleenkäynnistyksen)</translation>
-    </message>
     <message>
         <source>Reduced quality</source>
         <translation>Huononnettu laatu</translation>
     </message>
+    <message>
+        <source>Show ammo menu tooltips</source>
+        <translation>Näytä asevalikon vihjeet</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation>Kytke käyttöliittymän äänet päälle</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation>Kytke käyttöliittymän musiikki päälle</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
+        <translation>Käyttöliittymän tehosteet</translation>
+    </message>
 </context>
 <context>
     <name>QComboBox</name>
@@ -570,6 +749,18 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>Level</source>
         <translation>Taso</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation>(Järjestelmän oletus)</translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
@@ -577,10 +768,6 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>Team Members</source>
         <translation>Joukkueen jäsenet</translation>
     </message>
-    <message>
-        <source>Team</source>
-        <translation>Joukkue</translation>
-    </message>
     <message>
         <source>Fort</source>
         <translation>Linnake</translation>
@@ -617,6 +804,14 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>Basic Settings</source>
         <translation>Perusasetukset</translation>
     </message>
+    <message>
+        <source>Team Settings</source>
+        <translation>Joukkueasetukset</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Muut</translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -720,6 +915,47 @@ Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä p
         <source>Game scheme</source>
         <translation>Pelikaava</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation>% suutarimiinoja</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nimi</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Tyyppi</translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation>Hauta</translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation>Lippu</translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation>Ääni</translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation>Kieli</translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation>Käynnistä peli uudelleen ottaaksesi muutokset käyttöön</translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -793,8 +1029,8 @@ Ole hyvä ja tarkista asennuksesi</translation>
         <translation>Nimimerkki</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
-        <translation>Ole hyvä, ja syötä nimimerkkisi</translation>
+        <source>Please enter your nickname</source>
+        <translation>Ole hyvä ja syötä nimimerkkisi</translation>
     </message>
 </context>
 <context>
@@ -859,6 +1095,10 @@ Ole hyvä ja tarkista asennuksesi</translation>
         <source>Ready</source>
         <translation>Valmis</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation>Satunnainen joukkue</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
@@ -901,6 +1141,14 @@ Ole hyvä ja tarkista asennuksesi</translation>
         <source>Probabilities</source>
         <translation>Todennäköisyydet</translation>
     </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation>Ammukset laatikoissa</translation>
+    </message>
+    <message>
+        <source>Delays</source>
+        <translation>Viipeet</translation>
+    </message>
 </context>
 <context>
     <name>TCPBase</name>
@@ -963,6 +1211,30 @@ Ole hyvä ja tarkista asennuksesi</translation>
         <source>Add Mines</source>
         <translation>Lisää miinat</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation>Satunnainen Järjestys</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation>Kuningas</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation>Sijoita siilet</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation>Saman väriset jakavat ammukset</translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation>Ei palkkeja</translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1245,5 +1517,289 @@ tiedot</translation>
         <source>Keyboard</source>
         <translation>Näppäimistö</translation>
     </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation>Hiiri: Keskinappi</translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation>Hiiri: Oikea nappi</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation>Hiiri: Rulla ylös</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation>Hiiri: Rulla alas</translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation>Askelapalutin</translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation>Sarkain</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Tyhjennä</translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation>Rivinvaihto</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Tauko</translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation>Esc-näppäin</translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation>Välilyönti</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Poistonäppäin</translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation>Numpad 0</translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation>Numpad 1</translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation>Numpad 2</translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation>Numpad 3</translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation>Numpad 4</translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation>Numpad 5</translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation>Numpad 6</translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation>Numpad 7</translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation>Numpad 8</translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation>Numpad 9</translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation>Numpad .</translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation>Numpad /</translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation>Numpad *</translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation>Numpad -</translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation>Numpad +</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation>Rivinvaihto</translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation>=</translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation>Ylös</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>Alas</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>Oikea</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>Vasen</translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation>Lisää-nappi</translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation>Home-nappi</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation>End-nappi</translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation>Sivu ylös</translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation>Sivu alas</translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation>Num lock</translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation>Caps lock</translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation>Scroll lock</translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation>Oikea vaihtonäppäin</translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation>Vasen vaihtonäppäin</translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation>Oikea ctrl</translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation>Vasen ctrl</translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation>Oikea alt</translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation>Vasen alt</translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation>Oikea meta</translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation>Vasen meta</translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation>A-painike</translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation>B-painike</translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation>X-painike</translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation>Y-painike</translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation>LB-painike</translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation>RB-painike</translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation>Paluu-painike</translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation>Start-painike</translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation>Vasen tikku</translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation>Oikea tikku</translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation>Vasen tikku (Oikea)</translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation>Vasen tikku (Vasen)</translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation>Vasen tikku (Alas)</translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation>Vasen tikku (ylös)</translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation>Vasen liipasin</translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation>Oikea liipasin</translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation>Oikea tikku (Alas)</translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation>Oikea tikku (Ylös)</translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation>Oikea tikku (Oikea)</translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
+        <translation>Oikea tikku (Vasen)</translation>
+    </message>
+    <message>
+        <source>DPad</source>
+        <translation>DPad</translation>
+    </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
