@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="it">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="it">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -8,6 +8,20 @@
         <translation>nuovo</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>Mai</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>Ogni turno</numerusform>
+            <numerusform>Ogni %1 turni</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -27,16 +41,31 @@
         <translation>Modifica schemi</translation>
     </message>
 </context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation>%1 *** %2 è stato rimosso dalla tua lista ignorati</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation>%1 *** %2 è stato aggiunto alla tua lista ignorati</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation>%1 *** %2 è stato rimosso dalla tua lista amici</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation>%1 *** %2 è stato aggiunto alla tua lista amici</translation>
+    </message>
+</context>
 <context>
     <name>HWForm</name>
     <message>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>Inserisci il record dalla lista sottostante</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -53,13 +82,13 @@
         <source>new</source>
         <translation>nuovo</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>Inserisci il record dalla lista sottostante</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>Errore durante la lettura del file di configurazione dell&apos;allenamento</translation>
-    </message>
     <message>
         <source>en.txt</source>
         <translation>it.txt</translation>
@@ -107,6 +136,38 @@
         <source>Wacky</source>
         <translation>Stramba</translation>
     </message>
+    <message>
+        <source>Tunnel size</source>
+        <translation type="obsolete">Grandezza Tunnel</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished">Tipo</translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -139,7 +200,7 @@
     </message>
     <message>
         <source>Room destroyed</source>
-        <translation>Room distrutta</translation>
+        <translation>Stanza distrutta</translation>
     </message>
     <message>
         <source>You got kicked</source>
@@ -165,7 +226,7 @@ o scegli un altro nickname:</translation>
     </message>
     <message>
         <source>%1 *** %2 has joined</source>
-        <translation type="unfinished">%1 *** %2 si è unito</translation>
+        <translation>%1 *** %2 è entrato</translation>
     </message>
     <message>
         <source>%1 *** %2 has left (%3)</source>
@@ -187,16 +248,40 @@ o scegli un altro nickname:</translation>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>Messaggio del server:</translation>
+        <translation type="obsolete">Messaggio del server:</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>Inserisci messaggio</translation>
+        <translation type="obsolete">Inserisci messaggio</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
         <translation>Pulisci la cache degli account</translation>
     </message>
+    <message>
+        <source>Fetch data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set data</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageConnecting</name>
@@ -222,6 +307,20 @@ o scegli un altro nickname:</translation>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
         <translation>&lt;p&gt;Il premio per il miglior colpo è stato vinto da &lt;b&gt;%1&lt;/b&gt; , con &lt;b&gt;%2&lt;/b&gt; punti.&lt;/p&gt;</translation>
     </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Il miglior killer è &lt;b&gt;%1&lt;/b&gt; con &lt;b&gt;%2&lt;/b&gt; uccisione in un turno.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Il miglior killer è &lt;b&gt;%1&lt;/b&gt; con &lt;b&gt;%2&lt;/b&gt; uccisioni in un turno.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Durante questo round è stato ucciso &lt;b&gt;%1&lt;/b&gt; hedgehog in totale.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Un totale di &lt;b&gt;%1&lt;/b&gt; hedgehogs sono stati uccisi durante questo round.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageMain</name>
@@ -248,7 +347,7 @@ o scegli un altro nickname:</translation>
         <translation>Errore</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
+        <source>Please select server from the list above</source>
         <translation>Seleziona il server dalla lista sottostante</translation>
     </message>
 </context>
@@ -281,12 +380,20 @@ o scegli un altro nickname:</translation>
         <translation>Modifica squadra</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>Set di armi</translation>
+        <source>Delete team</source>
+        <translation>Elimina team</translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>Modifica</translation>
+        <source>New weapon scheme</source>
+        <translation>Nuovo schema armi</translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation>Modifica schema armi</translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation>Elimina schema armi</translation>
     </message>
 </context>
 <context>
@@ -295,10 +402,6 @@ o scegli un altro nickname:</translation>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>Seleziona un record dalla lista</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -319,6 +422,10 @@ o scegli un altro nickname:</translation>
         <source>Cannot delete file</source>
         <translation>Impossibile cancellare il file</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>Seleziona un record dalla lista</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -338,18 +445,10 @@ o scegli un altro nickname:</translation>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>Inserisci il nome della room</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>Seleziona la room dalla lista</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>Opzioni amministratore</translation>
@@ -361,14 +460,14 @@ o scegli un altro nickname:</translation>
     <message>
         <source>This game is in lobby.
 You may join and start playing once the game starts.</source>
-        <translation type="unfinished">Questa partita è nella lobby.
-Puoi entrare e iniziare a giocare quando la partita inzia.</translation>
+        <translation>Questa partita è nella lobby.
+Puoi entrare e iniziare a giocare quando la partita inizia.</translation>
     </message>
     <message>
         <source>This game is in progress.
 You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
         <translation>Questa partita è in corso.
-Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita per iniziare a giocare.</translation>
+Puoi entrare come spettatore ma dovrai aspettare la fine della partita per giocare.</translation>
     </message>
     <message>
         <source>%1 is the host. He may adjust settings and start the game.</source>
@@ -384,12 +483,38 @@ Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita
     </message>
     <message>
         <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
-        <translation>Lo Schema di Gioco definisce le opzioni generali e le prefernze come Tempo di Round, Sudden Death o Vampirismo.</translation>
+        <translation>Lo Schema di Gioco definisce le opzioni generali e le preferenze come Tempo di Round, Sudden Death o Vampirismo.</translation>
     </message>
     <message>
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
         <translation>Lo Schema delle Armi definisce le armi disponibili le loro munizioni.</translation>
     </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation>
+            <numerusform>E&apos; presente %1 utente connesso a questa stanza.</numerusform>
+            <numerusform>Sono presenti %1 utenti connessi a questa stanza.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation>
+            <numerusform>E&apos; presente %1 squadra partecipante in questa stanza.</numerusform>
+            <numerusform>Sono presenti %1 squadre partecipanti in questa stanza.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Inserisci il nome della stanza</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>Seleziona la stanza dalla lista</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
+        <translation>Labirinto Casuale</translation>
+    </message>
 </context>
 <context>
     <name>PageScheme</name>
@@ -453,6 +578,30 @@ Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita
         <source>All hogs have a personal forcefield</source>
         <translation>Tutti i ricci hanno un personale campo di forza</translation>
     </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>L&apos;ordine di gioco è casuale invece che nell&apos;ordine della stanza.</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>Gioca con un Re. Se il Re muore la tua squadra perderà.</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>Piazza a turno i tuoi ricci prima dell&apos;inizio della partita.</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation>Le munizioni sono condivise tra tutti i team che hanno lo stesso colore.</translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation>Disabilita le travi nella generazione di mappe casuali.</translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -514,6 +663,26 @@ Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita
         <source>Ban</source>
         <translation>Ban</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>Segui</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation>Ignora</translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation>Aggiungi amico</translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation>Togli ignora</translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation>Rimuovi amico</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -549,14 +718,26 @@ Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita
         <source>Append date and time to record file name</source>
         <translation>Concatena data e ora di registrazione al nome file</translation>
     </message>
-    <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation>Effetti del Frontend (richiede riavvio)</translation>
-    </message>
     <message>
         <source>Reduced quality</source>
         <translation>Qualità ridotta</translation>
     </message>
+    <message>
+        <source>Show ammo menu tooltips</source>
+        <translation>Mostra suggerimenti nel menu armi</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation>Abilita suoni nel frontend</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation>Abilita la musica nel frontend</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
+        <translation>Effetti nel frontend</translation>
+    </message>
 </context>
 <context>
     <name>QComboBox</name>
@@ -572,13 +753,21 @@ Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita
         <source>Level</source>
         <translation>Livello</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation>(Default di sistema)</translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation>labirinto generato...</translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation>Missione</translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
-    <message>
-        <source>Team</source>
-        <translation>Squadra</translation>
-    </message>
     <message>
         <source>Team Members</source>
         <translation>Membri della squadra</translation>
@@ -619,6 +808,14 @@ Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita
         <source>Basic Settings</source>
         <translation>Impostazioni di base</translation>
     </message>
+    <message>
+        <source>Team Settings</source>
+        <translation>Impostazioni dei Team</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Varie</translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -722,6 +919,48 @@ Puoi entrare e fare da spettatore ora, ma dovrai aspettare la fine della partita
         <source>Game scheme</source>
         <translation>Schema di gioco</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation>% Mine Difettose</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Tipo</translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation>Tomba</translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation>Bandiera</translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation>Voce</translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation>Locale</translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation>Riavvia il gioco per applicare</translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation>Questa versione SVN è &apos;work in progress&apos; e può non essere compatibile con le altre versioni del gioco.
+Alcune feature potrebbero essere incomplete o non funzionanti. Usatela a vostro rischio!</translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation>Esplosivi</translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -795,8 +1034,8 @@ Controllare la propria installazione</translation>
         <translation>Nickname</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
-        <translation>Per favore, inserisci il tuo nickname</translation>
+        <source>Please enter your nickname</source>
+        <translation>Per favore inserisci il tuo nickname</translation>
     </message>
 </context>
 <context>
@@ -861,6 +1100,10 @@ Controllare la propria installazione</translation>
         <source>Ready</source>
         <translation>Pronto</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation>Team Casuale</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
@@ -903,6 +1146,14 @@ Controllare la propria installazione</translation>
         <source>Probabilities</source>
         <translation>Probabilità</translation>
     </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation>Munizioni nelle casse</translation>
+    </message>
+    <message>
+        <source>Delays</source>
+        <translation>Ritardi</translation>
+    </message>
 </context>
 <context>
     <name>TCPBase</name>
@@ -965,6 +1216,30 @@ Controllare la propria installazione</translation>
         <source>Add Mines</source>
         <translation>Aggiungi mine</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation>Ordine Casuale</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation>Re</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation>Posiziona Ricci</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation>Munizioni Condivise</translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation>Disabilita Travi</translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1139,7 +1414,7 @@ hedgehogs</translation>
     </message>
     <message>
         <source>Camera and cursor controls</source>
-        <translation type="unfinished">Controlli per il mouse e la visualizzazione</translation>
+        <translation>Controlli camera e cursore</translation>
     </message>
     <message>
         <source>Other</source>
@@ -1154,19 +1429,19 @@ hedgehogs</translation>
     </message>
     <message>
         <source>Traverse gaps and obstacles by jumping:</source>
-        <translation>Salta e schiva gli ostacoli in questo percorso:</translation>
+        <translation>Scavalca buchi e ostacoli saltando:</translation>
     </message>
     <message>
         <source>Fire your selected weapon or trigger an utility item:</source>
-        <translation>Spara con la tua arma selezionata o usa uno strumento:</translation>
+        <translation>Spara con l&apos;arma selezionata o usa l&apos;attrezzo:</translation>
     </message>
     <message>
         <source>Pick a weapon or a target location under the cursor:</source>
-        <translation>Raccogli un&apos;arma o raggiungi un luogo selezionato dal mouse:</translation>
+        <translation>Raccogli un&apos;arma o mira con il cursore:</translation>
     </message>
     <message>
         <source>Switch your currently active hog (if possible):</source>
-        <translation>Scambia il tuo riccio attivo (se possibile):</translation>
+        <translation>Cambia il riccio attualmente attivo (se possibile):</translation>
     </message>
     <message>
         <source>Pick a weapon or utility item:</source>
@@ -1174,15 +1449,15 @@ hedgehogs</translation>
     </message>
     <message>
         <source>Set the timer on bombs and timed weapons:</source>
-        <translation>Configura il timer per le bombe e altre armi esplosive:</translation>
+        <translation>Imposta il timer su bombe e armi a tempo:</translation>
     </message>
     <message>
         <source>Move the camera to the active hog:</source>
-        <translation type="unfinished"></translation>
+        <translation>Muovi la camera verso il riccio attivo:</translation>
     </message>
     <message>
         <source>Move the cursor or camera without using the mouse:</source>
-        <translation type="unfinished"></translation>
+        <translation>Muovi il cursore o la camera senza usare il mouse:</translation>
     </message>
     <message>
         <source>Modify the camera&apos;s zoom level:</source>
@@ -1190,19 +1465,19 @@ hedgehogs</translation>
     </message>
     <message>
         <source>Talk to your team or all participants:</source>
-        <translation>Parla alla tua squadra o a tutti i giocatori:</translation>
+        <translation>Parla al tuo team o a tutti i partecipanti:</translation>
     </message>
     <message>
         <source>Pause, continue or leave your game:</source>
-        <translation>Pausa, continua o abbandona la partita:</translation>
+        <translation>Pausa, continua o lascia il gioco:</translation>
     </message>
     <message>
         <source>Modify the game&apos;s volume while playing:</source>
-        <translation>Modifica il volume del gioco durante la partita:</translation>
+        <translation>Modifica il volume del gioco in esecuzione:</translation>
     </message>
     <message>
         <source>Toggle fullscreen mode:</source>
-        <translation>Attiva/Disattiva schermo intero:</translation>
+        <translation>Modalità schermo intero:</translation>
     </message>
     <message>
         <source>Take a screenshot:</source>
@@ -1210,7 +1485,7 @@ hedgehogs</translation>
     </message>
     <message>
         <source>Toggle labels above hedgehogs:</source>
-        <translation>Attiva/Disattiva le etichete sopra i ricci:</translation>
+        <translation>Cambia le etichette sui ricci:</translation>
     </message>
 </context>
 <context>
@@ -1247,5 +1522,289 @@ hedgehogs</translation>
         <source>Keyboard</source>
         <translation>(Tastiera)</translation>
     </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation>Mouse: Tasto sinistro</translation>
+    </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation>Mouse: Tasto centrale</translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation>Mouse: Tasto destro</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation>Mouse: Scroll in su</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation>Mouse: Scroll in giù</translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation>Backspace</translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation>Tab</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Cancella</translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation>Invio</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausa</translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation>Esc</translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation>Spazio</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation>Numpad 0</translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation>Numpad 1</translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation>Numpad 2</translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation>Numpad 3</translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation>Numpad 4</translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation>Numpad 5</translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation>Numpad 6</translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation>Numpad 7</translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation>Numpad 8</translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation>Numpad 9</translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation>Numpad .</translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation>Numpad /</translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation>Numpad *</translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation>Numpad -</translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation>Numpad +</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation>Invio</translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation>Uguale</translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation>Su</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>Giù</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>Destra</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>Sinistra</translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation>Inserisci</translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation>Home</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation>Fine</translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation>Pagina su</translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation>Pagina giu</translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation>Num lock</translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation>Caps lock</translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation>Scroll lock</translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation>Shift destro</translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation>Shift sinistro</translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation>Ctrl destro</translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation>Ctrl sinistro</translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation>Alt destro</translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation>Alt sinistro</translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation>Meta destro</translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation>Meta sinistro</translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation>Tasto A</translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation>Tasto B</translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation>Tasto X</translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation>Tasto X</translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation>Tasto LB</translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation>Tasto RB</translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation>Tasto indietro</translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation>Tasto start</translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation>Leva sinistra</translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation>Leva destra</translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation>Leva sinistra (Destra)</translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation>Leva sinistra (Sinistra)</translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation>Leva sinistra (Giu)</translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation>Leva sinistra (Su)</translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation>Grilletto sinistro</translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation>Grilletto destro</translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation>Leva destra (Giu)</translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation>Leva destra (Su)</translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation>Leva destra (Destra)</translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
+        <translation>Leva destra (Sinistra)</translation>
+    </message>
+    <message>
+        <source>DPad</source>
+        <translation>DPad</translation>
+    </message>
 </context>
 </TS>
