@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="ru">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -6,6 +8,21 @@
         <translation>новый</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>Никогда</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>Каждый %1 ход</numerusform>
+            <numerusform>Каждые %1 хода</numerusform>
+            <numerusform>Каждые %1 ходов</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -25,6 +42,25 @@
         <translation>Редактировать схемы</translation>
     </message>
 </context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation>%1 *** %2 был удалён из вашего списка игнорирования</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation>%1 *** %2 был добавлен в ваш список игнорирования</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation>%1 *** %2 был удалён из вашего списка друзей</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation>%1 *** %2 был добавлен в ваш список друзей</translation>
+    </message>
+</context>
 <context>
     <name>HWForm</name>
     <message>
@@ -35,10 +71,6 @@
         <source>OK</source>
         <translation>ОК</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>Выберите запись из списка</translation>
-    </message>
     <message>
         <source>Cannot save record to file %1</source>
         <translation>Не могу сохранить запись в файл %1</translation>
@@ -51,6 +83,10 @@
         <source>new</source>
         <translation>новый</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>Выберите запись из списка</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
@@ -62,10 +98,6 @@
         <source>Cannot open demofile %1</source>
         <translation>Не могу открыть демо %1</translation>
     </message>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>Ошибка чтения файла тренировки</translation>
-    </message>
 </context>
 <context>
     <name>HWMapContainer</name>
@@ -105,6 +137,34 @@
         <source>Wacky</source>
         <translation>Необычные</translation>
     </message>
+    <message>
+        <source>Type</source>
+        <translation>Тип</translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation>Маленькие туннели</translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation>Средние туннели</translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation>Большие туннели</translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation>Маленькие островки</translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation>Средние островки</translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation>Большие островки</translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -185,16 +245,40 @@ or pick another nickname:</source>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>Сообщение сервера:</translation>
+        <translation type="obsolete">Сообщение сервера:</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>Установить сообщение</translation>
+        <translation type="obsolete">Установить сообщение</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
         <translation>Очистить кэш учётных записей</translation>
     </message>
+    <message>
+        <source>Fetch data</source>
+        <translation>Получить данные</translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation>Сообщение сервера для последней версии клиента:</translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation>Сообщение сервера для предыдущих версий клиента:</translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation>Номер протокола последнего релиза:</translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation>Предпросмотр сообщения сервера:</translation>
+    </message>
+    <message>
+        <source>Set data</source>
+        <translation>Установить данные</translation>
+    </message>
 </context>
 <context>
     <name>PageConnecting</name>
@@ -220,6 +304,22 @@ or pick another nickname:</source>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
         <translation>&lt;p&gt;Приз за лучший выстрел получает &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; пунктами урона.&lt;/p&gt;</translation>
     </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Лучший киллер ‒ это &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убитым за ход.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Лучший киллер ‒ это &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убитыми за ход.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Лучший киллер ‒ это &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убитыми за ход.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Всего &lt;b&gt;%1&lt;/b&gt; ёж был убит за этот поединок.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Всего &lt;b&gt;%1&lt;/b&gt; ежа были убиты за этот поединок.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Всего &lt;b&gt;%1&lt;/b&gt; ежей были убиты за этот поединок.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageMain</name>
@@ -246,7 +346,7 @@ or pick another nickname:</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
+        <source>Please select server from the list above</source>
         <translation>Выберите сервер из списка</translation>
     </message>
 </context>
@@ -279,12 +379,20 @@ or pick another nickname:</source>
         <translation>Изменить</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>Набор оружия</translation>
+        <source>Delete team</source>
+        <translation>Удалить команду</translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>Изменить</translation>
+        <source>New weapon scheme</source>
+        <translation>Новая схема оружия</translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation>Редактировать схему оружия</translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation>Удалить схему оружия</translation>
     </message>
 </context>
 <context>
@@ -293,10 +401,6 @@ or pick another nickname:</source>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>Выберите запись из списка</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>ОК</translation>
@@ -317,6 +421,10 @@ or pick another nickname:</source>
         <source>Cannot delete file</source>
         <translation>Не могу удалить файл</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>Выберите запись из списка</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -336,18 +444,10 @@ or pick another nickname:</source>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>Введите название комнаты</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>ОК</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>Выберите комнату из списка</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>Администрирование</translation>
@@ -388,6 +488,34 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
         <translation>Схема оружия определяет доступное оружие и число снарядов.</translation>
     </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation>
+            <numerusform>Всего %1 игрок находится в этой комнате.</numerusform>
+            <numerusform>Всего %1 игрока находятся в этой комнате.</numerusform>
+            <numerusform>Всего %1 игроков находятся в этой комнате.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation>
+            <numerusform>Всего %1 команда участвует в игре в этой комнате.</numerusform>
+            <numerusform>Всего %1 команды участвуют в игре в этой комнате.</numerusform>
+            <numerusform>Всего %1 команд участвуют в игре в этой комнате.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Введите название комнаты</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>Выберите комнату из списка</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
+        <translation>Случайный лабиринт</translation>
+    </message>
 </context>
 <context>
     <name>PageScheme</name>
@@ -451,6 +579,30 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>All hogs have a personal forcefield</source>
         <translation>Каждый ёжик в защитном поле</translation>
     </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>Порядок ходов случаен, а не является порядком команд в списке</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>Играть с Королём. Если он умирает, ваша сторона проигрывает.</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>Расставить ежей вручную перед игрой.</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation>Оружие совместно используется всеми командами с одним цветом.</translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation>Убрать балки из генерируемых карт.</translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation type="unfinished">Отключить добавляемые объекты на генерируемых картах.</translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -512,6 +664,26 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Ban</source>
         <translation>Заблокировать</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>Следовать</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation>Игнорировать</translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation>Добавить в друзья</translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation>Убрать игнорирование</translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation>Убирать из списка друзей</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
@@ -547,14 +719,26 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Append date and time to record file name</source>
         <translation>Указывать дату и время в названиях демок и сейвов</translation>
     </message>
-    <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation>Эффекты фронтенда (необходим перезапуск)</translation>
-    </message>
     <message>
         <source>Reduced quality</source>
         <translation>Пониженное качество</translation>
     </message>
+    <message>
+        <source>Show ammo menu tooltips</source>
+        <translation>Показывать подсказки к оружию</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation>Включить звуки в меню</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation>Включить музыку в меню</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
+        <translation>Эффекты в меню</translation>
+    </message>
 </context>
 <context>
     <name>QComboBox</name>
@@ -570,6 +754,18 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Level</source>
         <translation>Уровень</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation>(Системный по умолчанию)</translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation>случайный лабиринт...</translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation>Миссия</translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
@@ -577,10 +773,6 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Team Members</source>
         <translation>Состав команды</translation>
     </message>
-    <message>
-        <source>Team</source>
-        <translation>Команда</translation>
-    </message>
     <message>
         <source>Fort</source>
         <translation>Форт</translation>
@@ -617,6 +809,14 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Basic Settings</source>
         <translation>Основные настройки</translation>
     </message>
+    <message>
+        <source>Team Settings</source>
+        <translation>Настройки команды</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Разное</translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -720,6 +920,48 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Game scheme</source>
         <translation>Настройки игры</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation>% невзрывающихся мин</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Название</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Тип</translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation>Надгробие</translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation>Флаг</translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation>Голос</translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation>Язык</translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation>Перезапустите игру для применения</translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation>Взрывчатка</translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -793,8 +1035,8 @@ Please check your installation</source>
         <translation>Псевдоним</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
-        <translation>Пожалуйста, введите ваш псевдоним</translation>
+        <source>Please enter your nickname</source>
+        <translation>Пожалуйста введите ваш псевдоним</translation>
     </message>
 </context>
 <context>
@@ -859,6 +1101,10 @@ Please check your installation</source>
         <source>Ready</source>
         <translation>Готов</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation>Случайная команда</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
@@ -901,6 +1147,14 @@ Please check your installation</source>
         <source>Probabilities</source>
         <translation>Вероятности</translation>
     </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation>Оружие в ящиках</translation>
+    </message>
+    <message>
+        <source>Delays</source>
+        <translation>Задержки</translation>
+    </message>
 </context>
 <context>
     <name>TCPBase</name>
@@ -963,6 +1217,30 @@ Please check your installation</source>
         <source>Add Mines</source>
         <translation>Добавить мины</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation>Случайный порядок</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation>Король</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation>Расставить ежей</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation>Общее оружие в клане</translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation>Убрать балки</translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1148,101 +1426,385 @@ info</source>
     <name>binds (descriptions)</name>
     <message>
         <source>Move your hogs and aim:</source>
-        <translation type="unfinished"></translation>
+        <translation>Передвижение ежа и прицеливание:</translation>
     </message>
     <message>
         <source>Traverse gaps and obstacles by jumping:</source>
-        <translation type="unfinished"></translation>
+        <translation>Прохождение оврагов и препятствий прыжками:</translation>
     </message>
     <message>
         <source>Fire your selected weapon or trigger an utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation>Выстрел из выбранного оружия или активация утилиты:</translation>
     </message>
     <message>
         <source>Pick a weapon or a target location under the cursor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Выбор оружия или цели под курсором:</translation>
     </message>
     <message>
         <source>Switch your currently active hog (if possible):</source>
-        <translation type="unfinished"></translation>
+        <translation>Переключение вашего активного ежа (если возможно):</translation>
     </message>
     <message>
         <source>Pick a weapon or utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation>Подбор оружия или утилиты:</translation>
     </message>
     <message>
         <source>Set the timer on bombs and timed weapons:</source>
-        <translation type="unfinished"></translation>
+        <translation>Установка таймера на бомбы и оружие с таймером:</translation>
     </message>
     <message>
         <source>Move the camera to the active hog:</source>
-        <translation type="unfinished"></translation>
+        <translation>Передвижение камеры на активного ежа:</translation>
     </message>
     <message>
         <source>Move the cursor or camera without using the mouse:</source>
-        <translation type="unfinished"></translation>
+        <translation>Перемещение курсора или камеры без использования мыши:</translation>
     </message>
     <message>
         <source>Modify the camera&apos;s zoom level:</source>
-        <translation type="unfinished"></translation>
+        <translation>Изменение уровня увеличения камеры:</translation>
     </message>
     <message>
         <source>Talk to your team or all participants:</source>
-        <translation type="unfinished"></translation>
+        <translation>Разговор с командой или всеми участниками:</translation>
     </message>
     <message>
         <source>Pause, continue or leave your game:</source>
-        <translation type="unfinished"></translation>
+        <translation>Пауза, продолжение или выход из игры:</translation>
     </message>
     <message>
         <source>Modify the game&apos;s volume while playing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Изменение громкости в течение игры:</translation>
     </message>
     <message>
         <source>Toggle fullscreen mode:</source>
-        <translation type="unfinished"></translation>
+        <translation>Переключение полноэкранного режима:</translation>
     </message>
     <message>
         <source>Take a screenshot:</source>
-        <translation type="unfinished"></translation>
+        <translation>Создание скриншота:</translation>
     </message>
     <message>
         <source>Toggle labels above hedgehogs:</source>
-        <translation type="unfinished"></translation>
+        <translation>Переключение меток над ежами:</translation>
     </message>
 </context>
 <context>
     <name>binds (keys)</name>
     <message>
         <source>Axis</source>
-        <translation type="unfinished"></translation>
+        <translation>Ось</translation>
     </message>
     <message>
         <source>(Up)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Вверх)</translation>
     </message>
     <message>
         <source>(Down)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Вниз)</translation>
     </message>
     <message>
         <source>Hat</source>
-        <translation type="unfinished"></translation>
+        <translation>Шляпа</translation>
     </message>
     <message>
         <source>(Left)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Влево)</translation>
     </message>
     <message>
         <source>(Right)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Вправо)</translation>
     </message>
     <message>
         <source>Button</source>
-        <translation type="unfinished"></translation>
+        <translation>Кнопка</translation>
     </message>
     <message>
         <source>Keyboard</source>
+        <translation>Клавиатура</translation>
+    </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation>Мышь: Левая кнопка</translation>
+    </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation>Мышь: Средняя кнопка</translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation>Мышь: Правая кнопка</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation>Мышь: Колесо вверх</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation>Мышь: Колесо вниз</translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation>Забой</translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation>Tab</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Очистить</translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation>Return</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Пауза</translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation>Escape</translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation>Пробел</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Delete</translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation>Вверх</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>Вниз</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>Вправо</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>Влево</translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation>Правый shift</translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation>Левый shift</translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation>Правый ctrl</translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation>Левый ctrl</translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation>Правый alt</translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation>Левый alt</translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation>Ввод</translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DPad</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
