@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="sk">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -6,6 +8,21 @@
         <translation>nový</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>Nikdy</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>Každý %1 ťah</numerusform>
+            <numerusform>Každé %1 ťahy</numerusform>
+            <numerusform>Každých %1 ťahov</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -25,16 +42,31 @@
         <translation>Upraviť schémy</translation>
     </message>
 </context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation>%1 *** %2 bol(a) odstránený(á) zo zoznamu ignorovaných</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation>%1 *** %2 bol(a) pridaný(á) do zoznamu ignorovaných</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation>%1 *** %2 bol(a) odstránený(á) zo zoznamu priateľov</translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation>%1 *** %2 bol(a) pridaný(á) do zoznamu priateľov</translation>
+    </message>
+</context>
 <context>
     <name>HWForm</name>
     <message>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>Prosím, vyberte záznam zo zoznamu vyššie</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -51,13 +83,13 @@
         <source>new</source>
         <translation>nový</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>Prosím vyberte záznam zo zoznamu vyššie</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>Chyba počas čítania konfiguračného súboru pre tréning</translation>
-    </message>
     <message>
         <source>en.txt</source>
         <translation>sk.txt</translation>
@@ -105,6 +137,34 @@
         <source>Wacky</source>
         <translation>Pojašená</translation>
     </message>
+    <message>
+        <source>Type</source>
+        <translation>Typ</translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation>Malé tunely</translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation>Stredné tunely</translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation>Veľké tunely</translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation>Malé plávajúce ostrovčeky</translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation>Stredné plávajúce ostrovčeky</translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation>Veľké plávajúce ostrovčeky</translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -152,23 +212,26 @@
 registered on Hedgewars.org
 Please provide your password
 or pick another nickname:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaša prezývka %1 je
+zaregistrovaná na Hedgewars.org
+Prosím, zadajte heslo alebo
+si vyberte inú prezývku:</translation>
     </message>
     <message>
         <source>%1 *** %2 has joined the room</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2 prišiel do miestnosti</translation>
     </message>
     <message>
         <source>%1 *** %2 has joined</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2 sa pridal</translation>
     </message>
     <message>
         <source>%1 *** %2 has left (%3)</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2 odišiel (%3)</translation>
     </message>
     <message>
         <source>%1 *** %2 has left</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2 odišiel</translation>
     </message>
 </context>
 <context>
@@ -182,14 +245,38 @@ or pick another nickname:</source>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>Správa serveru:</translation>
+        <translation type="obsolete">Správa serveru:</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>Nastaviť správu</translation>
+        <translation type="obsolete">Nastaviť správu</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
+        <translation>Vymazať vyrovnávaciu pamäť účtov</translation>
+    </message>
+    <message>
+        <source>Fetch data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set data</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -217,6 +304,22 @@ or pick another nickname:</source>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
         <translation>&lt;p&gt;Ocenenie za najlepší zásah vyhral(a) &lt;b&gt;%1&lt;/b&gt; so ziskom &lt;b&gt;%2&lt;/b&gt; bodov.&lt;/p&gt;</translation>
     </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;jedným&lt;/b&gt; zabitím počas ťahu.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation>
+            <numerusform>&lt;p&gt;Celkovo bol v tomto kole zabitý &lt;b&gt;jeden&lt;/b&gt; ježko.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Celkovo boli v tomto kole zabití &lt;b&gt;%1&lt;/b&gt; ježkovia.&lt;/p&gt;</numerusform>
+            <numerusform>&lt;p&gt;Celkovo boli v tomto kole zabití &lt;b&gt;%1&lt;/b&gt; ježkovia.&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PageMain</name>
@@ -243,8 +346,8 @@ or pick another nickname:</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
-        <translation>Prosím, vyberte server zo zoznamu vyššie</translation>
+        <source>Please select server from the list above</source>
+        <translation>Prosím vyberte server zo zoznamu vyššie</translation>
     </message>
 </context>
 <context>
@@ -276,12 +379,20 @@ or pick another nickname:</source>
         <translation>Upraviť team</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>Sada zbraní</translation>
+        <source>Delete team</source>
+        <translation>Vymazať tím</translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>Úpravy</translation>
+        <source>New weapon scheme</source>
+        <translation>Nová schéma pre zbrane</translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation>Upraviť schému pre zbrane</translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation>Vymazať schému pre zbrane</translation>
     </message>
 </context>
 <context>
@@ -290,10 +401,6 @@ or pick another nickname:</source>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>Prosím, vyberte záznam zo zoznamu</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -314,6 +421,10 @@ or pick another nickname:</source>
         <source>Cannot delete file</source>
         <translation>Nemôžem vymazať súbor</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>Prosím vyberte záznam zo zoznamu</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -333,55 +444,77 @@ or pick another nickname:</source>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>Prosím, zadajte názov miestnosti</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>Prosím, vyberte miestnosť zo zoznamu</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>Vlastnosti pre admina</translation>
     </message>
     <message>
         <source>Room Name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Názov miestnosti:</translation>
     </message>
     <message>
         <source>This game is in lobby.
 You may join and start playing once the game starts.</source>
-        <translation type="unfinished"></translation>
+        <translation>Táto hra je v lobby.
+Môžete sa pridať a začať hru akonáhle hra skončí.</translation>
     </message>
     <message>
         <source>This game is in progress.
 You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
-        <translation type="unfinished"></translation>
+        <translation>Táto hra práve prebieha.
+Môžete sa pridať a sledovať hru, ale ak chcete hrať budete musieť počkať na koniec hry.</translation>
     </message>
     <message>
         <source>%1 is the host. He may adjust settings and start the game.</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 je hostiteľom. Može meniť nastavenia a spúšťať hru.</translation>
     </message>
     <message>
         <source>Random Map</source>
-        <translation type="unfinished"></translation>
+        <translation>Náhodná mapa</translation>
     </message>
     <message>
         <source>Games may be played on precreated or randomized maps.</source>
-        <translation type="unfinished"></translation>
+        <translation>Hry môžu byť hrané na predvytvorených alebo náhodných mapách.</translation>
     </message>
     <message>
         <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
-        <translation type="unfinished"></translation>
+        <translation>Schéma hry určuje všeobecné voľby ako napríklad Dĺžka kola, Režim rýchlej smrti alebo Vampírizmus.</translation>
     </message>
     <message>
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
-        <translation type="unfinished"></translation>
+        <translation>Schémy hry určuje dostupné zbrane a množstvo výzbroje.</translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation>
+            <numerusform>K tejto miestnosti je pripojený jeden klient.</numerusform>
+            <numerusform>K tejto miestnosti sú pripojení %1 klienti.</numerusform>
+            <numerusform>K tejto miestnosti je pripojených %1 klientov.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation>
+            <numerusform>V tejto miestnosti je jeden hrajúci team.</numerusform>
+            <numerusform>V tejto miestnosti sú %1 hrajúce teamy.</numerusform>
+            <numerusform>V tejto miestnosti je %1 hrajúcich teamov.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>Prosím zadajte názov miestnosti</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>Prosím vyberte miestnosť zo zoznamu</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
+        <translation>Náhodné bludisko</translation>
     </message>
 </context>
 <context>
@@ -446,6 +579,30 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>All hogs have a personal forcefield</source>
         <translation>Všetci ježkovia majú osobné silové pole</translation>
     </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>Poradie hrania je náhodné miesto poradia hráčov v miestnosti.</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>Hra s Kráľom. Ak zomrie, vaša strana prehráva.</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>Pred začatím hry sa súperi striedajú v umiestňovaní ježkov.</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation>Výzbroj je zdieľaná medzi všetkými tímami, ktoré majú tú istú farbu.</translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation>Zakázať trámy pri generovaní náhodných máp.</translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -507,12 +664,32 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Ban</source>
         <translation>Zakázať</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>Nasledovať</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation>Ignorovať</translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation>Pridať priateľa</translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation>Zrušiť ignorovanie</translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation>Odstrániť priateľa</translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
     <message>
         <source>Check for updates at startup</source>
-        <translation type="unfinished"></translation>
+        <translation>Kontrolovať aktualizácie pri štarte</translation>
     </message>
     <message>
         <source>Fullscreen</source>
@@ -543,12 +720,24 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <translation>Pripojiť dátum a čas k súboru so záznamom</translation>
     </message>
     <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation type="unfinished"></translation>
+        <source>Reduced quality</source>
+        <translation>Znížená kvalita</translation>
     </message>
     <message>
-        <source>Reduced quality</source>
-        <translation type="unfinished"></translation>
+        <source>Show ammo menu tooltips</source>
+        <translation>Zobrazovať nápovedu pre zbrane</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation>Povoliť zvuky vo frontende</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation>Povoliť hudbu vo frontende</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
+        <translation>Efekty vo frontende</translation>
     </message>
 </context>
 <context>
@@ -565,13 +754,21 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Level</source>
         <translation>Úroveň</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation>(Východzie nastavenie)</translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation>vygenerované bludisko..</translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation>Misia</translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
-    <message>
-        <source>Team</source>
-        <translation>Team</translation>
-    </message>
     <message>
         <source>Team Members</source>
         <translation>Členovia teamu</translation>
@@ -612,6 +809,14 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Basic Settings</source>
         <translation>Základné nastavenia</translation>
     </message>
+    <message>
+        <source>Team Settings</source>
+        <translation>Nastavenia tímu</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Rozličné</translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -715,6 +920,48 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Scheme Name:</source>
         <translation>Názov schémy:</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation>% Falošné míny</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Meno</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Typ</translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation>Hrobček</translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation>Vlajka</translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation>Hlasy</translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation>Jazykové nastavenia</translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation>Vyžaduje reštart hry</translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation>Toto zostavenie SVN je &apos;stále-vo-vývoji&apos; a nemusí byť kompatibilné s inými verziami hry.
+Niektoré vlastnosti nemusia fungovať alebo nemusia byť dokončené. Používajte na vlastné riziko!</translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation>Výbušniny</translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -785,11 +1032,11 @@ Skontrolujte si vašu inštaláciu</translation>
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished"></translation>
+        <translation>Prezývka</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
-        <translation type="unfinished"></translation>
+        <source>Please enter your nickname</source>
+        <translation>Prosím, zadajte vašu prezývku</translation>
     </message>
 </context>
 <context>
@@ -854,47 +1101,59 @@ Skontrolujte si vašu inštaláciu</translation>
         <source>Ready</source>
         <translation>Pripravený</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation>Náhodný tím</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
     <message>
         <source>Room Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Názov miestnosti</translation>
     </message>
     <message>
         <source>C</source>
-        <translation type="unfinished"></translation>
+        <translation>C</translation>
     </message>
     <message>
         <source>T</source>
-        <translation type="unfinished"></translation>
+        <translation>T</translation>
     </message>
     <message>
         <source>Owner</source>
-        <translation type="unfinished"></translation>
+        <translation>Majiteľ</translation>
     </message>
     <message>
         <source>Map</source>
-        <translation type="unfinished">Mapa</translation>
+        <translation>Mapa</translation>
     </message>
     <message>
         <source>Rules</source>
-        <translation type="unfinished"></translation>
+        <translation>Pravidlá</translation>
     </message>
     <message>
         <source>Weapons</source>
-        <translation type="unfinished"></translation>
+        <translation>Zbrane</translation>
     </message>
 </context>
 <context>
     <name>SelWeaponWidget</name>
     <message>
         <source>Weapon set</source>
-        <translation type="unfinished"></translation>
+        <translation>Sada zbraní</translation>
     </message>
     <message>
         <source>Probabilities</source>
-        <translation type="unfinished"></translation>
+        <translation>Pravdepodobnosti</translation>
+    </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation>Zbrane v krabiciach</translation>
+    </message>
+    <message>
+        <source>Delays</source>
+        <translation>Oneskorenie</translation>
     </message>
 </context>
 <context>
@@ -958,6 +1217,30 @@ Skontrolujte si vašu inštaláciu</translation>
         <source>Add Mines</source>
         <translation>Pridať míny</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation>Náhodné poradie</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation>Kráľ</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation>Umiestňovať ježkov</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation>Klan zdieľa výzbroj</translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation>Vypnúť trámy</translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1101,143 +1384,427 @@ ježkov</translation>
     </message>
     <message>
         <source>zoom in</source>
-        <translation type="unfinished"></translation>
+        <translation>priblíženie</translation>
     </message>
     <message>
         <source>zoom out</source>
-        <translation type="unfinished"></translation>
+        <translation>oddialenie</translation>
     </message>
     <message>
         <source>reset zoom</source>
-        <translation type="unfinished"></translation>
+        <translation>reštartovať priblíženie</translation>
     </message>
     <message>
         <source>long jump</source>
-        <translation type="unfinished"></translation>
+        <translation>dlhý skok</translation>
     </message>
     <message>
         <source>high jump</source>
-        <translation type="unfinished"></translation>
+        <translation>vysoký skok</translation>
     </message>
 </context>
 <context>
     <name>binds (categories)</name>
     <message>
         <source>Basic controls</source>
-        <translation type="unfinished"></translation>
+        <translation>Základné ovládanie</translation>
     </message>
     <message>
         <source>Weapon controls</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládanie zbraní</translation>
     </message>
     <message>
         <source>Camera and cursor controls</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládanie kurzora a kamery</translation>
     </message>
     <message>
         <source>Other</source>
-        <translation type="unfinished">Iné</translation>
+        <translation>Iné</translation>
     </message>
 </context>
 <context>
     <name>binds (descriptions)</name>
     <message>
         <source>Move your hogs and aim:</source>
-        <translation type="unfinished"></translation>
+        <translation>Presun ježka a mierenie:</translation>
     </message>
     <message>
         <source>Traverse gaps and obstacles by jumping:</source>
-        <translation type="unfinished"></translation>
+        <translation>Prekoná priepasti a prekážky skokom:</translation>
     </message>
     <message>
         <source>Fire your selected weapon or trigger an utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vypáli vami zvolenú zbraň alebo zapne nástroj:</translation>
     </message>
     <message>
         <source>Pick a weapon or a target location under the cursor:</source>
-        <translation type="unfinished"></translation>
+        <translation>Položí zbraň alebo vyberie cieľ v mieste pod kurzorom:</translation>
     </message>
     <message>
         <source>Switch your currently active hog (if possible):</source>
-        <translation type="unfinished"></translation>
+        <translation>Prepne vášho momentálne vybraného ježka (ak je to možné):</translation>
     </message>
     <message>
         <source>Pick a weapon or utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation>Zodvihne zbraň alebo nástroj:</translation>
     </message>
     <message>
         <source>Set the timer on bombs and timed weapons:</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastaví časovač na bombách a iných zbraniach s časovou rozbuškou:</translation>
     </message>
     <message>
         <source>Move the camera to the active hog:</source>
-        <translation type="unfinished"></translation>
+        <translation>Presunie kameru na aktívneho ježka:</translation>
     </message>
     <message>
         <source>Move the cursor or camera without using the mouse:</source>
-        <translation type="unfinished"></translation>
+        <translation>Presunie kurzor alebo kameru bez použitia myši:</translation>
     </message>
     <message>
         <source>Modify the camera&apos;s zoom level:</source>
-        <translation type="unfinished"></translation>
+        <translation>Zmeniť stupeň priblíženia kamery:</translation>
     </message>
     <message>
         <source>Talk to your team or all participants:</source>
-        <translation type="unfinished"></translation>
+        <translation>Umožní vám rozhovor s vašim teamom alebo všetkými účastníkmi hry:</translation>
     </message>
     <message>
         <source>Pause, continue or leave your game:</source>
-        <translation type="unfinished"></translation>
+        <translation>Pauza, pokračovanie alebo opustenie hry:</translation>
     </message>
     <message>
         <source>Modify the game&apos;s volume while playing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Zmena hlasitosti v hre počas hrania:</translation>
     </message>
     <message>
         <source>Toggle fullscreen mode:</source>
-        <translation type="unfinished"></translation>
+        <translation>Prepne celoobrazovkový režim:</translation>
     </message>
     <message>
         <source>Take a screenshot:</source>
-        <translation type="unfinished"></translation>
+        <translation>Urobí snímok obrazovky:</translation>
     </message>
     <message>
         <source>Toggle labels above hedgehogs:</source>
-        <translation type="unfinished"></translation>
+        <translation>Prepnúť nápisy nad ježkami:</translation>
     </message>
 </context>
 <context>
     <name>binds (keys)</name>
     <message>
         <source>Axis</source>
-        <translation type="unfinished"></translation>
+        <translation>Os</translation>
     </message>
     <message>
         <source>(Up)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Hore)</translation>
     </message>
     <message>
         <source>(Down)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Dole)</translation>
     </message>
     <message>
         <source>Hat</source>
-        <translation type="unfinished"></translation>
+        <translation>Klobúk</translation>
     </message>
     <message>
         <source>(Left)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Vľavo)</translation>
     </message>
     <message>
         <source>(Right)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Vpravo)</translation>
     </message>
     <message>
         <source>Button</source>
-        <translation type="unfinished"></translation>
+        <translation>Tlačidlo</translation>
     </message>
     <message>
         <source>Keyboard</source>
+        <translation>Klávesnica</translation>
+    </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation>Myš: Ľavé tlačidlo</translation>
+    </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation>Myš: Prostredné tlačidlo</translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation>Myš: Pravé tlačidlo</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation>Myš: Kolečko smerom nahor</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation>Myš: Kolečko smerom nadol</translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation>Backspace</translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation>Tabulátor</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>Clear</translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation>Enter</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pause</translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation>Escape</translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation>Medzera</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Delete</translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation>Numpad 0</translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation>Numpad 1</translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation>Numpad 2</translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation>Numpad 3</translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation>Numpad 4</translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation>Numpad 5</translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation>Numpad 6</translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation>Numpad 7</translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation>Numpad 8</translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation>Numpad 9</translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation>Numpad .</translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation>Numpad /</translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation>Numpad *</translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation>Numpad -</translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation>Numpad +</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation>Enter</translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation>Rovná sa</translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation>Hore</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>Dole</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>Vpravo</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>Vľavo</translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation>Insert</translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation>Home</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation>End</translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation>Page up</translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation>Page down</translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation>Num lock</translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation>Caps lock</translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation>Scroll lock</translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation>Pravý shift</translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation>Ľavý shift</translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation>Pravý ctrl</translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation>Ľavý ctrl</translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation>Pravý alt</translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation>Ľavý alt</translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation>Pravý meta</translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation>Ľavý meta</translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation>Tlačidlo A</translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation>Tlačidlo B</translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation>Tlačidlo X</translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation>Tlačidlo Y</translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation>Tlačidlo LB</translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation>Tlačidlo RB</translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation>Tlačidlo Back</translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation>Tlačidlo Start</translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation>Joystick doľava</translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation>Joystick doprava</translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation>Ľavý prepínač</translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation>Pravý prepínač</translation>
+    </message>
+    <message>
+        <source>DPad</source>
+        <translation>DPad</translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
