@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0" language="zh_CN">
 <context>
     <name>AmmoSchemeModel</name>
     <message>
@@ -6,6 +8,19 @@
         <translation>新</translation>
     </message>
 </context>
+<context>
+    <name>FreqSpinBox</name>
+    <message>
+        <source>Never</source>
+        <translation>从不</translation>
+    </message>
+    <message numerus="yes">
+        <source>Every %1 turn</source>
+        <translation>
+            <numerusform>每 %1 个回合</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>GameCFGWidget</name>
     <message>
@@ -18,11 +33,30 @@
     </message>
     <message>
         <source>Edit schemes</source>
-        <translation>修改游戏设置</translation>
+        <translation type="unfinished">修改游戏设置</translation>
     </message>
     <message>
         <source>Edit weapons</source>
-        <translation>改变武器设置</translation>
+        <translation type="unfinished">修改武器设置</translation>
+    </message>
+</context>
+<context>
+    <name>HWChatWidget</name>
+    <message>
+        <source>%1 *** %2 has been removed from your ignore list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your ignore list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been removed from your friends list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 *** %2 has been added to your friends list</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -35,10 +69,6 @@
         <source>OK</source>
         <translation>确认</translation>
     </message>
-    <message>
-        <source>Please, select record from the list above</source>
-        <translation>请选择一个记录</translation>
-    </message>
     <message>
         <source>Cannot save record to file %1</source>
         <translation>无法录入文件 %1</translation>
@@ -51,6 +81,10 @@
         <source>new</source>
         <translation>新</translation>
     </message>
+    <message>
+        <source>Please select record from the list above</source>
+        <translation>请选择一个记录</translation>
+    </message>
 </context>
 <context>
     <name>HWGame</name>
@@ -62,10 +96,6 @@
         <source>Cannot open demofile %1</source>
         <translation>DEMO %1 打不开</translation>
     </message>
-    <message>
-        <source>Error reading training config file</source>
-        <translation>训练设置文件无法读取</translation>
-    </message>
 </context>
 <context>
     <name>HWMapContainer</name>
@@ -105,6 +135,34 @@
         <source>Wacky</source>
         <translation>曲折</translation>
     </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Small tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large tunnels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Small floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Medium floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Large floating islands</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HWNetServersModel</name>
@@ -152,23 +210,26 @@
 registered on Hedgewars.org
 Please provide your password
 or pick another nickname:</source>
-        <translation type="unfinished"></translation>
+        <translation>您的昵称%1
+在Hedgewars.org已注册
+请输入您的密码
+或选择另一个昵称:</translation>
     </message>
     <message>
         <source>%1 *** %2 has joined the room</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2已经进入房间</translation>
     </message>
     <message>
         <source>%1 *** %2 has joined</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2已经进入</translation>
     </message>
     <message>
         <source>%1 *** %2 has left (%3)</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2已经离开(%3)</translation>
     </message>
     <message>
         <source>%1 *** %2 has left</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 *** %2已经离开</translation>
     </message>
 </context>
 <context>
@@ -182,16 +243,40 @@ or pick another nickname:</source>
     <name>PageAdmin</name>
     <message>
         <source>Server message:</source>
-        <translation>服务器信息：</translation>
+        <translation type="obsolete">服务器信息：</translation>
     </message>
     <message>
         <source>Set message</source>
-        <translation>设定信息</translation>
+        <translation type="obsolete">设定信息</translation>
     </message>
     <message>
         <source>Clear Accounts Cache</source>
         <translation>清空账户缓存</translation>
     </message>
+    <message>
+        <source>Fetch data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for latest version:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Server message for previous versions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Latest version protocol number:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MOTD preview:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set data</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageConnecting</name>
@@ -215,7 +300,19 @@ or pick another nickname:</source>
     <name>PageGameStats</name>
     <message>
         <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
-        <translation>&lt;p&gt;最佳射手是&lt;b&gt;%1&lt;/b&gt;。伤害 &lt;b&gt;%2&lt;/b&gt;点。&lt;/p&gt;</translation>
+        <translation type="unfinished">&lt;p&gt;最佳射手是 &lt;b&gt;%1&lt;/b&gt;。伤害 &lt;b&gt;%2&lt;/b&gt;点。&lt;/p&gt;</translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
+        <translation type="unfinished">
+            <numerusform>&lt;p&gt;最佳杀手是 &lt;b&gt;%1&lt;/b&gt;单回合击杀刺猬数:&lt;b&gt;%2&lt;/b&gt;&lt;/p&gt;</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
+        <translation type="unfinished">
+            <numerusform>&lt;p&gt;本轮总共有&lt;b&gt;%1&lt;/b&gt;只刺猬被击杀&lt;/p&gt;</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -243,7 +340,7 @@ or pick another nickname:</source>
         <translation>错误</translation>
     </message>
     <message>
-        <source>Please, select server from the list above</source>
+        <source>Please select server from the list above</source>
         <translation>请选择一个服务器</translation>
     </message>
 </context>
@@ -251,7 +348,7 @@ or pick another nickname:</source>
     <name>PageNetGame</name>
     <message>
         <source>Control</source>
-        <translation>Ctrl</translation>
+        <translation>房间管理</translation>
     </message>
 </context>
 <context>
@@ -276,12 +373,20 @@ or pick another nickname:</source>
         <translation>修改队伍设定</translation>
     </message>
     <message>
-        <source>Weapons set</source>
-        <translation>新武器设定</translation>
+        <source>Delete team</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Edit</source>
-        <translation>修改当前武器设定</translation>
+        <source>New weapon scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit weapon scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete weapon scheme</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -290,10 +395,6 @@ or pick another nickname:</source>
         <source>Error</source>
         <translation>错误</translation>
     </message>
-    <message>
-        <source>Please, select record from the list</source>
-        <translation>请从列表选择记录</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>确认</translation>
@@ -314,6 +415,10 @@ or pick another nickname:</source>
         <source>Cannot delete file</source>
         <translation>不能删除文件</translation>
     </message>
+    <message>
+        <source>Please select record from the list</source>
+        <translation>请从列表选择记录</translation>
+    </message>
 </context>
 <context>
     <name>PageRoomsList</name>
@@ -333,54 +438,72 @@ or pick another nickname:</source>
         <source>Error</source>
         <translation>错误</translation>
     </message>
-    <message>
-        <source>Please, enter room name</source>
-        <translation>请键入房间名</translation>
-    </message>
     <message>
         <source>OK</source>
         <translation>确认</translation>
     </message>
-    <message>
-        <source>Please, select room from the list</source>
-        <translation>请从列表选中房间</translation>
-    </message>
     <message>
         <source>Admin features</source>
         <translation>管理员功能</translation>
     </message>
     <message>
         <source>Room Name:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">房间名:</translation>
     </message>
     <message>
         <source>This game is in lobby.
 You may join and start playing once the game starts.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">游戏正在等待中。
+您可以加入等待游戏开始。</translation>
     </message>
     <message>
         <source>This game is in progress.
 You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">游戏正在进行中。
+您可以加入观战但必须等游戏结束才能参与游戏。</translation>
     </message>
     <message>
         <source>%1 is the host. He may adjust settings and start the game.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1 是房主，他可以调整设置、开始游戏。</translation>
     </message>
     <message>
         <source>Random Map</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">随机地图</translation>
     </message>
     <message>
         <source>Games may be played on precreated or randomized maps.</source>
-        <translation type="unfinished"></translation>
+        <translation>游戏可以在预先创建或者随机产生的地图上进行。</translation>
     </message>
     <message>
         <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">游戏设置包括一般选项例如回合时间，突然死亡或吸血模式。</translation>
     </message>
     <message>
         <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
+        <translation type="unfinished">武器设置包括可以选用的武器和弹药数量。</translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 clients connected to this room.</source>
+        <translation type="unfinished">
+            <numerusform>有 %1 个客户端连接到这个房间。</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>There are %1 teams participating in this room.</source>
+        <translation type="unfinished">
+            <numerusform>有 %1 个队伍加入这个房间。</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Please enter room name</source>
+        <translation>请键入房间名</translation>
+    </message>
+    <message>
+        <source>Please select room from the list</source>
+        <translation>请从列表选中房间</translation>
+    </message>
+    <message>
+        <source>Random Maze</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -388,7 +511,7 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
     <name>PageScheme</name>
     <message>
         <source>New</source>
-        <translation>新游戏</translation>
+        <translation>新模式</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -446,6 +569,30 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Seconds</source>
         <translation>秒钟</translation>
     </message>
+    <message>
+        <source>Order of play is random instead of in room order.</source>
+        <translation>随机出场顺序</translation>
+    </message>
+    <message>
+        <source>Play with a King. If he dies, your side dies.</source>
+        <translation>国王不能死!!</translation>
+    </message>
+    <message>
+        <source>Take turns placing your hedgehogs before the start of play.</source>
+        <translation>在开局前手动放置刺猬</translation>
+    </message>
+    <message>
+        <source>Ammo is shared between all teams that share a colour.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable girders when generating random maps.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable land objects when generating random maps.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PageSelectWeapon</name>
@@ -507,16 +654,36 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Ban</source>
         <translation>屏蔽</translation>
     </message>
+    <message>
+        <source>Follow</source>
+        <translation>跟随</translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add friend</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unignore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove friend</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QCheckBox</name>
     <message>
         <source>Check for updates at startup</source>
-        <translation type="unfinished"></translation>
+        <translation>启动时检查程序升级</translation>
     </message>
     <message>
         <source>Enable sound</source>
-        <translation>开启音效</translation>
+        <translation type="unfinished">开启游戏音效</translation>
     </message>
     <message>
         <source>Fullscreen</source>
@@ -532,7 +699,7 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
     </message>
     <message>
         <source>Enable music</source>
-        <translation>开启音乐</translation>
+        <translation type="unfinished">开启游戏音乐</translation>
     </message>
     <message>
         <source>Frontend fullscreen</source>
@@ -543,11 +710,23 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <translation>记录名称中包含具体时间日期</translation>
     </message>
     <message>
-        <source>Frontend effects (requires restart)</source>
-        <translation type="unfinished"></translation>
+        <source>Reduced quality</source>
+        <translation type="unfinished">降低显示效果</translation>
     </message>
     <message>
-        <source>Reduced quality</source>
+        <source>Show ammo menu tooltips</source>
+        <translation type="unfinished">显示武器提示信息</translation>
+    </message>
+    <message>
+        <source>Enable frontend sounds</source>
+        <translation type="unfinished">开启菜单音效</translation>
+    </message>
+    <message>
+        <source>Enable frontend music</source>
+        <translation type="unfinished">开启菜单音乐</translation>
+    </message>
+    <message>
+        <source>Frontend effects</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -565,6 +744,18 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Level</source>
         <translation>Lv 级别</translation>
     </message>
+    <message>
+        <source>(System default)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>generated maze...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mission</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QGroupBox</name>
@@ -572,10 +763,6 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Team Members</source>
         <translation>成员</translation>
     </message>
-    <message>
-        <source>Team</source>
-        <translation>队伍</translation>
-    </message>
     <message>
         <source>Fort</source>
         <translation>城堡模式</translation>
@@ -612,6 +799,14 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Basic Settings</source>
         <translation>基本设置</translation>
     </message>
+    <message>
+        <source>Team Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLabel</name>
@@ -715,6 +910,47 @@ You may join and spectate now but you&apos;ll have to wait for the game to end t
         <source>Mines</source>
         <translation>地雷</translation>
     </message>
+    <message>
+        <source>% Dud Mines</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grave</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flag</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Voice</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Locale</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Restart game to apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
+Some features might be broken or incomplete. Use at your own risk!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Explosives</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QLineEdit</name>
@@ -785,11 +1021,11 @@ Please check your installation</source>
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">昵称</translation>
     </message>
     <message>
-        <source>Please, enter your nickname</source>
-        <translation type="unfinished"></translation>
+        <source>Please enter your nickname</source>
+        <translation type="unfinished">请输入您的昵称</translation>
     </message>
 </context>
 <context>
@@ -854,24 +1090,28 @@ Please check your installation</source>
         <source>Ready</source>
         <translation>准备好了</translation>
     </message>
+    <message>
+        <source>Random Team</source>
+        <translation type="unfinished">随机队伍分配</translation>
+    </message>
 </context>
 <context>
     <name>QTableWidget</name>
     <message>
         <source>Room Name</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">房间名</translation>
     </message>
     <message>
         <source>C</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">人数</translation>
     </message>
     <message>
         <source>T</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">队伍</translation>
     </message>
     <message>
         <source>Owner</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">创建者</translation>
     </message>
     <message>
         <source>Map</source>
@@ -879,7 +1119,7 @@ Please check your installation</source>
     </message>
     <message>
         <source>Rules</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">规则</translation>
     </message>
     <message>
         <source>Weapons</source>
@@ -890,10 +1130,18 @@ Please check your installation</source>
     <name>SelWeaponWidget</name>
     <message>
         <source>Weapon set</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">武器设置</translation>
     </message>
     <message>
         <source>Probabilities</source>
+        <translation type="unfinished">几率</translation>
+    </message>
+    <message>
+        <source>Ammo in boxes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delays</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -958,6 +1206,30 @@ Please check your installation</source>
         <source>Artillery</source>
         <translation>射术</translation>
     </message>
+    <message>
+        <source>Random Order</source>
+        <translation type="unfinished">随机顺序</translation>
+    </message>
+    <message>
+        <source>King</source>
+        <translation type="unfinished">国王模式</translation>
+    </message>
+    <message>
+        <source>Place Hedgehogs</source>
+        <translation type="unfinished">手动放置</translation>
+    </message>
+    <message>
+        <source>Clan Shares Ammo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable Girders</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disable Land Objects</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>binds</name>
@@ -1051,7 +1323,7 @@ Please check your installation</source>
     </message>
     <message>
         <source>find hedgehog</source>
-        <translation>找到 刺猬</translation>
+        <translation>寻找刺猬</translation>
     </message>
     <message>
         <source>ammo menu</source>
@@ -1101,38 +1373,38 @@ info</source>
     </message>
     <message>
         <source>zoom in</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">放大</translation>
     </message>
     <message>
         <source>zoom out</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">缩小</translation>
     </message>
     <message>
         <source>reset zoom</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">重置</translation>
     </message>
     <message>
         <source>long jump</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">跳远</translation>
     </message>
     <message>
         <source>high jump</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">跳高</translation>
     </message>
 </context>
 <context>
     <name>binds (categories)</name>
     <message>
         <source>Basic controls</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">基本控制</translation>
     </message>
     <message>
         <source>Weapon controls</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">武器控制</translation>
     </message>
     <message>
         <source>Camera and cursor controls</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">镜头和光标控制</translation>
     </message>
     <message>
         <source>Other</source>
@@ -1143,101 +1415,385 @@ info</source>
     <name>binds (descriptions)</name>
     <message>
         <source>Move your hogs and aim:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">移动、瞄准：</translation>
     </message>
     <message>
         <source>Traverse gaps and obstacles by jumping:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">越过障碍：</translation>
     </message>
     <message>
         <source>Fire your selected weapon or trigger an utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">开火、使用物品：</translation>
     </message>
     <message>
         <source>Pick a weapon or a target location under the cursor:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">选取武器、目的地：</translation>
     </message>
     <message>
         <source>Switch your currently active hog (if possible):</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">切换刺猬（如果可用）：</translation>
     </message>
     <message>
         <source>Pick a weapon or utility item:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">选取武器、物品：</translation>
     </message>
     <message>
         <source>Set the timer on bombs and timed weapons:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">设置定时炸弹等武器时间：</translation>
     </message>
     <message>
         <source>Move the camera to the active hog:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">移动镜头到选中刺猬：</translation>
     </message>
     <message>
         <source>Move the cursor or camera without using the mouse:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">不用鼠标移动光标或镜头：</translation>
     </message>
     <message>
         <source>Modify the camera&apos;s zoom level:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">调整镜头放大倍数：</translation>
     </message>
     <message>
         <source>Talk to your team or all participants:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">同队友或全部参与者对话：</translation>
     </message>
     <message>
         <source>Pause, continue or leave your game:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">暂停、继续或离开游戏：</translation>
     </message>
     <message>
         <source>Modify the game&apos;s volume while playing:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">调整游戏时音量：</translation>
     </message>
     <message>
         <source>Toggle fullscreen mode:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">全屏模式：</translation>
     </message>
     <message>
         <source>Take a screenshot:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">截图：</translation>
     </message>
     <message>
         <source>Toggle labels above hedgehogs:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">切换刺猬标签显示方式：</translation>
     </message>
 </context>
 <context>
     <name>binds (keys)</name>
     <message>
         <source>Axis</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">轴</translation>
     </message>
     <message>
         <source>(Up)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">上</translation>
     </message>
     <message>
         <source>(Down)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">下</translation>
     </message>
     <message>
         <source>Hat</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">帽子</translation>
     </message>
     <message>
         <source>(Left)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">左</translation>
     </message>
     <message>
         <source>(Right)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">右</translation>
     </message>
     <message>
         <source>Button</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">按键</translation>
     </message>
     <message>
         <source>Keyboard</source>
+        <translation type="unfinished">键盘</translation>
+    </message>
+    <message>
+        <source>Mouse: Left button</source>
+        <translation>鼠标：左键</translation>
+    </message>
+    <message>
+        <source>Mouse: Middle button</source>
+        <translation>鼠标：中键</translation>
+    </message>
+    <message>
+        <source>Mouse: Right button</source>
+        <translation>鼠标：右键</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel up</source>
+        <translation>鼠标滚轮：向上</translation>
+    </message>
+    <message>
+        <source>Mouse: Wheel down</source>
+        <translation>鼠标滚轮：向下</translation>
+    </message>
+    <message>
+        <source>Backspace</source>
+        <translation>退格键</translation>
+    </message>
+    <message>
+        <source>Tab</source>
+        <translation>制表键</translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation>清除</translation>
+    </message>
+    <message>
+        <source>Return</source>
+        <translation>返回</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>暂停键</translation>
+    </message>
+    <message>
+        <source>Escape</source>
+        <translation>退出键</translation>
+    </message>
+    <message>
+        <source>Space</source>
+        <translation>空格键</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>删除键</translation>
+    </message>
+    <message>
+        <source>Numpad 0</source>
+        <translation>小键盘0</translation>
+    </message>
+    <message>
+        <source>Numpad 1</source>
+        <translation>小键盘1</translation>
+    </message>
+    <message>
+        <source>Numpad 2</source>
+        <translation>小键盘2</translation>
+    </message>
+    <message>
+        <source>Numpad 3</source>
+        <translation>小键盘3</translation>
+    </message>
+    <message>
+        <source>Numpad 4</source>
+        <translation>小键盘4</translation>
+    </message>
+    <message>
+        <source>Numpad 5</source>
+        <translation>小键盘5</translation>
+    </message>
+    <message>
+        <source>Numpad 6</source>
+        <translation>小键盘6</translation>
+    </message>
+    <message>
+        <source>Numpad 7</source>
+        <translation>小键盘7</translation>
+    </message>
+    <message>
+        <source>Numpad 8</source>
+        <translation>小键盘8</translation>
+    </message>
+    <message>
+        <source>Numpad 9</source>
+        <translation>小键盘9</translation>
+    </message>
+    <message>
+        <source>Numpad .</source>
+        <translation>小键盘.</translation>
+    </message>
+    <message>
+        <source>Numpad /</source>
+        <translation>小键盘/</translation>
+    </message>
+    <message>
+        <source>Numpad *</source>
+        <translation>小键盘*</translation>
+    </message>
+    <message>
+        <source>Numpad -</source>
+        <translation>小键盘-</translation>
+    </message>
+    <message>
+        <source>Numpad +</source>
+        <translation>小键盘+</translation>
+    </message>
+    <message>
+        <source>Enter</source>
+        <translation>回车键</translation>
+    </message>
+    <message>
+        <source>Equals</source>
+        <translation>等于</translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation>上</translation>
+    </message>
+    <message>
+        <source>Down</source>
+        <translation>下</translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation>右</translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation>左</translation>
+    </message>
+    <message>
+        <source>Insert</source>
+        <translation>插入键</translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation>Home键</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation>End键</translation>
+    </message>
+    <message>
+        <source>Page up</source>
+        <translation>向上翻页键</translation>
+    </message>
+    <message>
+        <source>Page down</source>
+        <translation>向下翻页键</translation>
+    </message>
+    <message>
+        <source>Num lock</source>
+        <translation>小键盘数字锁</translation>
+    </message>
+    <message>
+        <source>Caps lock</source>
+        <translation>大小写切换键</translation>
+    </message>
+    <message>
+        <source>Scroll lock</source>
+        <translation>Scroll Lock键</translation>
+    </message>
+    <message>
+        <source>Right shift</source>
+        <translation>右Shift键</translation>
+    </message>
+    <message>
+        <source>Left shift</source>
+        <translation>左Shift键</translation>
+    </message>
+    <message>
+        <source>Right ctrl</source>
+        <translation>右Ctrl键</translation>
+    </message>
+    <message>
+        <source>Left ctrl</source>
+        <translation>左Ctrl键</translation>
+    </message>
+    <message>
+        <source>Right alt</source>
+        <translation>右Alt键</translation>
+    </message>
+    <message>
+        <source>Left alt</source>
+        <translation>左Alt键</translation>
+    </message>
+    <message>
+        <source>Right meta</source>
+        <translation>右meta键</translation>
+    </message>
+    <message>
+        <source>Left meta</source>
+        <translation>左meta键</translation>
+    </message>
+    <message>
+        <source>A button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>B button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>X button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LB button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RB button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Back button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start button</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Left)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left trigger</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right trigger</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Down)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Up)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Right)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right stick (Left)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DPad</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
